@@ -149,7 +149,16 @@ public enum MetricType {
                                                 ", not including throttled connections", LogLevel.OFF, PLong.INSTANCE),
     CLIENT_METADATA_CACHE_MISS_COUNTER("cmcm", "Number of cache misses for the CQSI cache.", LogLevel.DEBUG, PLong.INSTANCE),
     CLIENT_METADATA_CACHE_HIT_COUNTER("cmch", "Number of cache hits for the CQSI cache.", LogLevel.DEBUG, PLong.INSTANCE),
-    PAGED_ROWS_COUNTER("prc", "Number of dummy rows returned to client due to paging.", LogLevel.DEBUG, PLong.INSTANCE),
+    CLIENT_METADATA_CACHE_EVICTION_COUNTER("cmce", "Number of cache evictions for the CQSI cache" +
+            ".", LogLevel.DEBUG,  PLong.INSTANCE),
+    CLIENT_METADATA_CACHE_REMOVAL_COUNTER("cmcr", "Number of cache removals for the CQSI cache.",
+            LogLevel.DEBUG, PLong.INSTANCE),
+    CLIENT_METADATA_CACHE_ADD_COUNTER("cmca", "Number of cache adds for the CQSI cache.",
+            LogLevel.DEBUG, PLong.INSTANCE),
+    CLIENT_METADATA_CACHE_ESTIMATED_USED_SIZE("cmcu", "Estimated used size of the CQSI cache.",
+            LogLevel.DEBUG, PLong.INSTANCE),
+    PAGED_ROWS_COUNTER("prc", "Number of dummy rows returned to client due to paging.",
+            LogLevel.DEBUG, PLong.INSTANCE),
 
     // hbase metrics
     COUNT_RPC_CALLS("rp", "Number of RPC calls",LogLevel.DEBUG, PLong.INSTANCE),
