@@ -1099,7 +1099,7 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
         indexScan.setTimeRange(scan.getTimeRange().getMin(), scan.getTimeRange().getMax());
         scanRanges.initializeScan(indexScan);
         SkipScanFilter skipScanFilter = scanRanges.getSkipScanFilter();
-        indexScan.setFilter(new SkipScanFilter(skipScanFilter, true));
+        indexScan.setFilter(new SkipScanFilter(skipScanFilter, true, true));
         indexScan.setRaw(true);
         indexScan.readAllVersions();
         indexScan.setCacheBlocks(false);
@@ -1502,7 +1502,7 @@ public abstract class GlobalIndexRegionScanner extends BaseRegionScanner {
             ScanRanges scanRanges = ScanRanges.createPointLookup(keys);
             scanRanges.initializeScan(incrScan);
             SkipScanFilter skipScanFilter = scanRanges.getSkipScanFilter();
-            incrScan.setFilter(new SkipScanFilter(skipScanFilter, true));
+            incrScan.setFilter(new SkipScanFilter(skipScanFilter, true, true));
             //putting back the min time to 0 for index and data reads
             incrScan.setTimeRange(0, scan.getTimeRange().getMax());
             scan.setTimeRange(0, scan.getTimeRange().getMax());
