@@ -22,14 +22,13 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyList;
-import static org.mockito.Matchers.anyListOf;
-import static org.mockito.Matchers.anyLong;
-import static org.mockito.Matchers.anyMap;
-import static org.mockito.Matchers.anySetOf;
-import static org.mockito.Matchers.eq;
-import static org.mockito.Matchers.isNull;
+import static org.mockito.ArgumentMatchers.any;
+import static org.mockito.ArgumentMatchers.anyList;
+import static org.mockito.ArgumentMatchers.anyLong;
+import static org.mockito.ArgumentMatchers.anyMap;
+import static org.mockito.ArgumentMatchers.anySet;
+import static org.mockito.ArgumentMatchers.eq;
+import static org.mockito.ArgumentMatchers.isNull;
 import static org.mockito.Mockito.never;
 import static org.mockito.Mockito.reset;
 import static org.mockito.Mockito.times;
@@ -112,14 +111,14 @@ public class AppendOnlySchemaIT extends ParallelStatsDisabledIT {
                     fail("Create Table should not fail");
                 }
             }
-            
+
             // verify getTable rpcs
             verify(connectionQueryServices, never())
                     .getTable((PName) isNull(), AdditionalMatchers.aryEq(new byte[0]),
-                            AdditionalMatchers.aryEq(Bytes.toBytes(viewName)), anyLong(), anyLong());
+                        AdditionalMatchers.aryEq(Bytes.toBytes(viewName)), anyLong(), anyLong());
             
             // verify no create table rpcs
-            verify(connectionQueryServices, never()).createTable(anyListOf(Mutation.class),
+            verify(connectionQueryServices, never()).createTable(anyList(),
                 any(byte[].class), any(PTableType.class), anyMap(), anyList(), any(byte[][].class),
                 eq(false), eq(false), eq(false), any(PTable.class));
             reset(connectionQueryServices);
@@ -141,9 +140,9 @@ public class AppendOnlySchemaIT extends ParallelStatsDisabledIT {
             // if not verify exists is true one call to add column table with empty mutation list (which does not make a rpc) 
             // else verify no add column calls
             verify(connectionQueryServices, notExists ? times(1) : never() )
-                    .addColumn(eq(Collections.<Mutation>emptyList()), any(PTable.class),
-                            any(PTable.class), anyMap(), anySetOf(String.class),
-                            anyListOf(PColumn.class));
+                    .addColumn(eq(Collections.<Mutation>emptyList()), any(), any(),
+                            any(), anyMap(), anySet(),
+                            anyList());
 
             // upsert one row
             conn2.createStatement().execute("UPSERT INTO " + viewName + "(hostName, metricVal) VALUES('host2', 2.0)");
