@@ -35,7 +35,8 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
-import org.apache.hadoop.mapred.FileAlreadyExistsException;
+import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.Admin;
 import org.apache.phoenix.end2end.index.IndexTestUtil;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.mapreduce.CsvBulkLoadTool;
@@ -46,7 +47,9 @@ import org.apache.phoenix.schema.PTableKey;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.phoenix.util.DateUtil;
 import org.apache.phoenix.util.PhoenixRuntime;
+import org.apache.phoenix.util.QueryUtil;
 import org.apache.phoenix.util.ReadOnlyProps;
+import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.TestUtil;
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -146,12 +149,10 @@ public class CsvBulkLoadToolIT extends BaseOwnClusterIT {
                     "--table", "table1",
                     "--schema", "s",
                     "--zookeeper", zkQuorum});
-            fail("Bulk loading error should have happened earlier");
-        } catch (Exception e){
-            assertTrue(e.getMessage().contains("Bulk Loading error: Bulk loading is disabled for " +
-                    "non empty tables with global indexes, because it will corrupt " +
-                    "the global index table in most cases.\n" +
-                    "Use the --corruptindexes option to override this check."));
+            assertTrue("Bulk loading error should have happened earlier", exitCode != 0);
+        } catch (Exception e) {
+            fail("Tools should return non-zero exit codes on failure"
+                    + " instead of throwing an exception");
         }
 
         ResultSet rs = stmt.executeQuery("SELECT id, name, t FROM s.table1 ORDER BY id");
@@ -393,7 +394,7 @@ public class CsvBulkLoadToolIT extends BaseOwnClusterIT {
                 + " (FIRST_NAME ASC)"
                 + " INCLUDE (LAST_NAME)";
         stmt.execute(ddl);
-        
+
         FileSystem fs = FileSystem.get(getUtility().getConfiguration());
         FSDataOutputStream outputStream = fs.create(new Path("/tmp/input3.csv"));
         PrintWriter printWriter = new PrintWriter(outputStream);
@@ -512,23 +513,98 @@ public class CsvBulkLoadToolIT extends BaseOwnClusterIT {
         }
     }
 
+    @Test
+    public void testImportWithDifferentPhysicalName() throws Exception {
+        String schemaName = "S_" + generateUniqueName();
+        String tableName = "TBL_" + generateUniqueName();
+        String indexTableName = String.format("%s_IDX", tableName);
+        String fullTableName = SchemaUtil.getTableName(schemaName, tableName);
+        String fullIndexTableName = SchemaUtil.getTableName(schemaName, indexTableName);
+        Statement stmt = conn.createStatement();
+        stmt.execute("CREATE TABLE " + fullTableName + "(ID INTEGER NOT NULL PRIMARY KEY, "
+                + "FIRST_NAME VARCHAR, LAST_NAME VARCHAR)");
+        String ddl = "CREATE  INDEX " + indexTableName + " ON " + fullTableName + "(FIRST_NAME ASC)";
+        stmt.execute(ddl);
+        String newTableName = LogicalTableNameIT.NEW_TABLE_PREFIX + generateUniqueName();
+        String fullNewTableName = SchemaUtil.getTableName(schemaName, newTableName);
+        try (Admin admin = conn.unwrap(PhoenixConnection.class).getQueryServices().getAdmin()) {
+            String snapshotName = new StringBuilder(tableName).append("-Snapshot").toString();
+            admin.snapshot(snapshotName, TableName.valueOf(fullTableName));
+            admin.cloneSnapshot(snapshotName, TableName.valueOf(fullNewTableName));
+        }
+        LogicalTableNameIT.renameAndDropPhysicalTable(conn, "NULL", schemaName, tableName, newTableName, false);
+
+        String csvName = "/tmp/input_logical_name.csv";
+        FileSystem fs = FileSystem.get(getUtility().getConfiguration());
+        FSDataOutputStream outputStream = fs.create(new Path(csvName));
+        PrintWriter printWriter = new PrintWriter(outputStream);
+        printWriter.println("1,FirstName 1,LastName 1");
+        printWriter.println("2,FirstName 2,LastName 2");
+        printWriter.close();
+
+        CsvBulkLoadTool csvBulkLoadTool = new CsvBulkLoadTool();
+        csvBulkLoadTool.setConf(getUtility().getConfiguration());
+        int
+                exitCode =
+                csvBulkLoadTool
+                        .run(new String[] { "--input", csvName, "--table", tableName,
+                                "--schema", schemaName,
+                                "--zookeeper", zkQuorum });
+        assertEquals(0, exitCode);
+
+        ResultSet rs = stmt.executeQuery("SELECT /*+ NO_INDEX */ id, FIRST_NAME FROM " + fullTableName + " where first_name='FirstName 2'");
+        assertTrue(rs.next());
+        assertEquals(2, rs.getInt(1));
+        assertEquals("FirstName 2", rs.getString(2));
+        String selectFromIndex = "SELECT FIRST_NAME FROM " + fullTableName + " where FIRST_NAME='FirstName 1'";
+        rs = stmt.executeQuery("EXPLAIN " + selectFromIndex);
+        assertTrue(QueryUtil.getExplainPlan(rs).contains(indexTableName));
+        rs = stmt.executeQuery(selectFromIndex);
+        assertTrue(rs.next());
+        assertEquals("FirstName 1", rs.getString(1));
+
+        String csvNameForIndex = "/tmp/input_logical_name_index.csv";
+        // Now just run the tool on the index table and check that the index has extra row.
+        outputStream = fs.create(new Path(csvNameForIndex));
+        printWriter = new PrintWriter(outputStream);
+        printWriter.println("3,FirstName 3,LastName 3");
+        printWriter.close();
+        exitCode = csvBulkLoadTool
+                        .run(new String[] { "--input", csvNameForIndex, "--table", tableName,
+                                "--schema", schemaName,
+                                "--index-table", indexTableName, "--zookeeper", zkQuorum,
+                                "--corruptindexes"});
+        assertEquals(0, exitCode);
+        selectFromIndex = "SELECT FIRST_NAME FROM " + fullTableName + " where FIRST_NAME='FirstName 3'";
+        rs = stmt.executeQuery("EXPLAIN " + selectFromIndex);
+        assertTrue(QueryUtil.getExplainPlan(rs).contains(indexTableName));
+        rs = stmt.executeQuery(selectFromIndex);
+        assertTrue(rs.next());
+        assertEquals("FirstName 3", rs.getString(1));
+        rs.close();
+        stmt.close();
+
+        IndexTestUtil.assertRowsForEmptyColValue(conn, fullIndexTableName,
+            QueryConstants.VERIFIED_BYTES);
+    }
+
     @Test
     public void testInvalidArguments() {
         String tableName = "TABLE8";
         CsvBulkLoadTool csvBulkLoadTool = new CsvBulkLoadTool();
         csvBulkLoadTool.setConf(getUtility().getConfiguration());
         try {
-            csvBulkLoadTool.run(new String[] {
+            int exitCode = csvBulkLoadTool.run(new String[] {
                 "--input", "/tmp/input4.csv",
                 "--table", tableName,
                 "--zookeeper", zkQuorum });
-            fail(String.format("Table %s not created, hence should fail",tableName));
+            assertTrue(String.format("Table %s not created, hence should fail", tableName),
+                exitCode != 0);
         } catch (Exception ex) {
-            assertTrue(ex instanceof IllegalArgumentException); 
-            assertTrue(ex.getMessage().contains(String.format("Table %s not found", tableName)));
-        }
+            fail("Tools should return non-zero exit codes on failure"
+                    + " instead of throwing an exception");        }
     }
-    
+
     @Test
     public void testAlreadyExistsOutputPath() {
         String tableName = "TABLE9";
@@ -537,7 +613,7 @@ public class CsvBulkLoadToolIT extends BaseOwnClusterIT {
             Statement stmt = conn.createStatement();
             stmt.execute("CREATE TABLE " + tableName + "(ID INTEGER NOT NULL PRIMARY KEY, "
                     + "FIRST_NAME VARCHAR, LAST_NAME VARCHAR)");
-            
+
             FileSystem fs = FileSystem.get(getUtility().getConfiguration());
             fs.create(new Path(outputPath));
             FSDataOutputStream outputStream = fs.create(new Path("/tmp/input9.csv"));
@@ -545,18 +621,21 @@ public class CsvBulkLoadToolIT extends BaseOwnClusterIT {
             printWriter.println("1,FirstName 1,LastName 1");
             printWriter.println("2,FirstName 2,LastName 2");
             printWriter.close();
-            
+
             CsvBulkLoadTool csvBulkLoadTool = new CsvBulkLoadTool();
             csvBulkLoadTool.setConf(getUtility().getConfiguration());
-            csvBulkLoadTool.run(new String[] {
+            int exitCode = csvBulkLoadTool.run(new String[] {
                 "--input", "/tmp/input9.csv",
                 "--output", outputPath,
                 "--table", tableName,
                 "--zookeeper", zkQuorum });
-            
-            fail(String.format("Output path %s already exists. hence, should fail",outputPath));
+
+            assertTrue(
+                String.format("Output path %s already exists. hence, should fail", outputPath),
+                exitCode != 0);
         } catch (Exception ex) {
-            assertTrue(ex instanceof FileAlreadyExistsException); 
+            fail("Tools should return non-zero exit codes when fail,"
+                + " instead of throwing an exception");
         }
     }
 
