@@ -34,7 +34,9 @@ import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.QueryUtil;
 import org.junit.Before;
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 
+@Category(ParallelStatsDisabledTest.class)
 public class DistinctPrefixFilterIT extends ParallelStatsDisabledIT {
     private static final String PREFIX = "SERVER DISTINCT PREFIX";
     private String testTableF;
