@@ -27,13 +27,22 @@ import java.util.Set;
 import java.util.regex.Pattern;
 import java.util.regex.PatternSyntaxException;
 
+import org.apache.hadoop.conf.Configured;
 import org.apache.hadoop.hbase.ClassFinder;
 import org.apache.hadoop.hbase.ClassFinder.FileNameFilter;
 import org.apache.hadoop.hbase.ClassTestFinder;
+import org.apache.hadoop.hbase.HBaseConfiguration;
 import org.apache.hadoop.hbase.IntegrationTestingUtility;
-import org.apache.hadoop.hbase.util.AbstractHBaseTool;
+import org.apache.hadoop.util.Tool;
 import org.apache.hadoop.util.ToolRunner;
-import org.apache.hbase.thirdparty.org.apache.commons.cli.CommandLine;
+import org.apache.phoenix.thirdparty.org.apache.commons.cli.Option;
+import org.apache.phoenix.thirdparty.com.google.common.annotations.VisibleForTesting;
+import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLine;
+import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLineParser;
+import org.apache.phoenix.thirdparty.org.apache.commons.cli.DefaultParser;
+import org.apache.phoenix.thirdparty.org.apache.commons.cli.HelpFormatter;
+import org.apache.phoenix.thirdparty.org.apache.commons.cli.Options;
+import org.apache.phoenix.thirdparty.org.apache.commons.cli.ParseException;
 import org.junit.internal.TextListener;
 import org.junit.runner.Description;
 import org.junit.runner.JUnitCore;
@@ -46,20 +55,66 @@ import org.slf4j.LoggerFactory;
  * This class drives the End2End tests suite execution against an
  * already deployed distributed cluster.
  */
-public class End2EndTestDriver extends AbstractHBaseTool {
+public class End2EndTestDriver extends Configured implements Tool {
     
     private static final Logger LOGGER = LoggerFactory.getLogger(End2EndTestDriver.class);
-    private static final String SHORT_REGEX_ARG = "r";
-    private static final String SKIP_TESTS = "n";
-    
+
+    private static Option SHORT_REGEX_OPTION = new Option("r", true, "Java regex to use selecting tests to run: e.g. .*TestBig.*" +
+            " will select all tests that include TestBig in their name.  Default: " +
+            ".*end2end.*");
+    private static Option SKIP_TESTS_OPTION = new Option("n", false, "Print list of End2End test suits without running them.");
+
     private End2EndTestFilter end2endTestFilter = new End2EndTestFilter();
     private boolean skipTests = false;
-    
 
     public static void main(String[] args) throws Exception {
       int ret = ToolRunner.run(new End2EndTestDriver(), args);
       System.exit(ret);
     }
+
+    @Override
+    public int run(String[] args) throws Exception {
+        try {
+            parseOptions(args);
+        } catch (IllegalStateException e) {
+            printHelpAndExit(e.getMessage(), getOptions());
+            return -1;
+        }
+        setConf(HBaseConfiguration.addHbaseResources(getConf()));
+        return doWork();
+    }
+
+
+    /**
+     * Parses the commandline arguments, throws IllegalStateException if mandatory arguments are
+     * missing.
+     * @param args supplied command line arguments
+     * @return the parsed command line
+     */
+    @VisibleForTesting
+    public CommandLine parseOptions(String[] args) {
+
+        final Options options = getOptions();
+
+        CommandLineParser parser = DefaultParser.builder().
+                setAllowPartialMatching(false).
+                setStripLeadingAndTrailingQuotes(false).
+                build();
+        CommandLine cmdLine = null;
+        try {
+            cmdLine = parser.parse(options, args);
+        } catch (ParseException e) {
+            printHelpAndExit("Error parsing command line options: " + e.getMessage(), options);
+        }
+
+        String testFilterString = cmdLine.getOptionValue(SHORT_REGEX_OPTION);
+        if (testFilterString != null) {
+          end2endTestFilter.setPattern(testFilterString);
+        }
+        skipTests = cmdLine.hasOption(SKIP_TESTS_OPTION);
+
+        return cmdLine;
+    }
     
     public static class End2EndFileNameFilter implements FileNameFilter {
 
@@ -72,6 +127,7 @@ public class End2EndTestDriver extends AbstractHBaseTool {
 
     public class End2EndTestFilter extends ClassTestFinder.TestClassFilter {
       private Pattern testFilterRe = Pattern.compile(".*end2end.*");
+
       public End2EndTestFilter() {
         super();
       }
@@ -105,23 +161,22 @@ public class End2EndTestDriver extends AbstractHBaseTool {
       }
     }
 
-    @Override
-    protected void addOptions() {
-      addOptWithArg(SHORT_REGEX_ARG, 
-        "Java regex to use selecting tests to run: e.g. .*TestBig.*" +
-        " will select all tests that include TestBig in their name.  Default: " +
-        ".*end2end.*");
-      addOptNoArg(SKIP_TESTS, 
-          "Print list of End2End test suits without running them.");
+    private Options getOptions() {
+        final Options options = new Options();
+        options.addOption(SHORT_REGEX_OPTION);
+        options.addOption(SKIP_TESTS_OPTION);
+        return options;
     }
 
-    @Override
-    protected void processOptions(CommandLine cmd) {
-      String testFilterString = cmd.getOptionValue(SHORT_REGEX_ARG, null);
-      if (testFilterString != null) {
-        end2endTestFilter.setPattern(testFilterString);
-      }
-      skipTests = cmd.hasOption(SKIP_TESTS);
+    private void printHelpAndExit(String errorMessage, Options options) {
+        System.err.println(errorMessage);
+        printHelpAndExit(options, 1);
+    }
+
+    private void printHelpAndExit(Options options, int exitCode) {
+        HelpFormatter formatter = new HelpFormatter();
+        formatter.printHelp("help", options);
+        System.exit(exitCode);
     }
 
     /**
@@ -193,10 +248,9 @@ public class End2EndTestDriver extends AbstractHBaseTool {
     };
 
     
-    @Override
     protected int doWork() throws Exception {
       //this is called from the command line, so we should set to use the distributed cluster
-      IntegrationTestingUtility.setUseDistributedCluster(conf);
+      IntegrationTestingUtility.setUseDistributedCluster(getConf());
       Class<?>[] classes = findEnd2EndTestClasses();
       System.out.println("Found " + classes.length + " end2end tests to run:");
       for (Class<?> aClass : classes) {
@@ -210,4 +264,5 @@ public class End2EndTestDriver extends AbstractHBaseTool {
 
       return result.wasSuccessful() ? 0 : 1;
     }
+
 }
