@@ -47,6 +47,7 @@ import org.apache.phoenix.util.ByteUtil;
 import org.apache.phoenix.util.EnvironmentEdge;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.PhoenixRuntime;
+import org.apache.phoenix.util.ScanUtil;
 import org.junit.BeforeClass;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
@@ -165,7 +166,7 @@ public class ExplainPlanWithStatsEnabledIT extends ParallelStatsEnabledIT {
             ResultSet rs = conn.createStatement().executeQuery(sql);
             assertFalse(rs.next());
             Estimate info = getByteRowEstimates(conn, sql, binds);
-            assertEquals((Long) 390L, info.estimatedBytes);
+            assertEquals((Long) 691L, info.estimatedBytes);
             assertEquals((Long) 10L, info.estimatedRows);
             assertTrue(info.estimateInfoTs > 0);
 
@@ -204,7 +205,7 @@ public class ExplainPlanWithStatsEnabledIT extends ParallelStatsEnabledIT {
                 assertTrue(rs.next());
             }
             Estimate info = getByteRowEstimates(conn, sql, binds);
-            assertEquals((Long) 390L, info.estimatedBytes);
+            assertEquals((Long) 691L, info.estimatedBytes);
             assertEquals((Long) 10L, info.estimatedRows);
             assertTrue(info.estimateInfoTs > 0);
         }
@@ -1256,12 +1257,11 @@ public class ExplainPlanWithStatsEnabledIT extends ParallelStatsEnabledIT {
     private void validatePropertyOnViewIndex(String viewName, String viewIndexName, boolean useStats, Connection conn,
             Connection tenantConn) throws SQLException, TableNotFoundException {
         // fetch the latest view ptable
-        PhoenixRuntime.getTableNoCache(tenantConn, viewName);
+        tenantConn.unwrap(PhoenixConnection.class).getTableNoCache(viewName);
         PhoenixConnection phxConn = conn.unwrap(PhoenixConnection.class);
         PTable viewIndex = phxConn.getTable(new PTableKey(phxConn.getTenantId(), viewIndexName));
         assertEquals("USE_STATS_FOR_PARALLELIZATION property set incorrectly", useStats,
-                PhoenixConfigurationUtil
-                        .getStatsForParallelizationProp(tenantConn.unwrap(PhoenixConnection.class), viewIndex));
+                ScanUtil.getStatsForParallelizationProp(tenantConn.unwrap(PhoenixConnection.class), viewIndex));
     }
 
 }
