@@ -26,8 +26,10 @@ import java.sql.DriverManager;
 import java.sql.ResultSet;
 
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 
 
+@Category(ParallelStatsDisabledTest.class)
 public class LastValueFunctionIT extends ParallelStatsDisabledIT {
 
     @Test
