@@ -25,14 +25,17 @@ import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.coprocessor.CompactionScanner;
 import org.apache.phoenix.coprocessorclient.BaseScannerRegionObserverConstants;
 import org.apache.phoenix.exception.SQLExceptionCode;
+import org.apache.phoenix.jdbc.PhoenixResultSet;
 import org.apache.phoenix.query.BaseTest;
 import org.apache.phoenix.query.QueryServices;
+import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.ManualEnvironmentEdge;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.QueryUtil;
 import org.apache.phoenix.util.ReadOnlyProps;
+import org.apache.phoenix.util.SchemaUtil;
 import org.apache.phoenix.util.TestUtil;
 import org.junit.After;
 import org.junit.Assert;
@@ -60,6 +63,10 @@ import static org.apache.phoenix.util.TestUtil.assertRowExistsAtSCN;
 import static org.apache.phoenix.util.TestUtil.assertRowHasExpectedValueAtSCN;
 import static org.apache.phoenix.util.TestUtil.assertTableHasTtl;
 import static org.apache.phoenix.util.TestUtil.assertTableHasVersions;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.assertNotNull;
 
 @Category(NeedsOwnMiniClusterTest.class)
 @RunWith(Parameterized.class)
@@ -81,6 +88,8 @@ public class MaxLookbackExtendedIT extends BaseTest {
         Map<String, String> props = Maps.newHashMapWithExpectedSize(2);
         props.put(QueryServices.GLOBAL_INDEX_ROW_AGE_THRESHOLD_TO_DELETE_MS_ATTRIB, Long.toString(0));
         props.put(BaseScannerRegionObserverConstants.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(MAX_LOOKBACK_AGE));
+        props.put("hbase.procedure.remote.dispatcher.delay.msec", "0");
+        props.put(HRegion.MEMSTORE_PERIODIC_FLUSH_INTERVAL, "0");
         setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
     }
 
@@ -248,8 +257,8 @@ public class MaxLookbackExtendedIT extends BaseTest {
             long beforeFirstCompactSCN = EnvironmentEdgeManager.currentTimeMillis();
             injectEdge.incrementValue(1); //new ts for major compaction
             majorCompact(dataTable);
-            majorCompact(indexTable);
             assertRawRowCount(conn, dataTable, rowsPlusDeleteMarker);
+            majorCompact(indexTable);
             assertRawRowCount(conn, indexTable, rowsPlusDeleteMarker);
             //wait for the lookback time. After this compactions should purge the deleted row
             injectEdge.incrementValue(MAX_LOOKBACK_AGE * 1000);
@@ -266,10 +275,14 @@ public class MaxLookbackExtendedIT extends BaseTest {
                 " values ('c', 'cd', 'cde', 'cdef')");
             conn.commit();
             injectEdge.incrementValue(1L);
+            flush(dataTable);
             majorCompact(dataTable);
-            majorCompact(indexTable);
             // Deleted row versions should be removed.
             assertRawRowCount(conn, dataTable, ROWS_POPULATED);
+
+            flush(indexTable);
+            majorCompact(indexTable);
+            // Deleted row versions should be removed.
             assertRawRowCount(conn, indexTable, ROWS_POPULATED);
 
             //deleted row should be gone, but not deleted row should still be there.
@@ -281,6 +294,62 @@ public class MaxLookbackExtendedIT extends BaseTest {
         }
     }
 
+    @Test(timeout=60000L)
+    public void testViewIndexIsCompacted() throws Exception {
+        String baseTable =  SchemaUtil.getTableName("SCHEMA1", generateUniqueName());
+        String globalViewName = generateUniqueName();
+        String fullGlobalViewName = SchemaUtil.getTableName("SCHEMA2", globalViewName);
+        String globalViewIdx =  generateUniqueName();
+        TableName dataTable = TableName.valueOf(baseTable);
+        TableName indexTable = TableName.valueOf("_IDX_" + baseTable);
+        try (Connection conn = DriverManager.getConnection(getUrl())) {
+            conn.createStatement().execute("CREATE TABLE " + baseTable
+                    + " (TENANT_ID CHAR(15) NOT NULL, PK2 INTEGER NOT NULL, PK3 INTEGER NOT NULL, "
+                    + "COL1 VARCHAR, COL2 VARCHAR, COL3 CHAR(15) CONSTRAINT PK PRIMARY KEY"
+                    + "(TENANT_ID, PK2, PK3)) MULTI_TENANT=true");
+            conn.createStatement().execute("CREATE VIEW " + fullGlobalViewName
+                    + " AS SELECT * FROM " + baseTable);
+            conn.createStatement().execute("CREATE INDEX " + globalViewIdx + " ON "
+                    + fullGlobalViewName + " (COL1) INCLUDE (COL2)");
+
+            conn.createStatement().executeUpdate("UPSERT INTO  " + fullGlobalViewName
+                    + " (TENANT_ID, PK2, PK3, COL1, COL2) VALUES ('TenantId1',1, 2, 'a', 'b')");
+            conn.commit();
+
+            String query = "SELECT COL2 FROM " + fullGlobalViewName + " WHERE  COL1 = 'a'";
+            // Verify that query uses the global view index
+            ResultSet rs = conn.createStatement().executeQuery(query);
+            PTable table = ((PhoenixResultSet)rs).getContext().getCurrentTable().getTable();
+            assertTrue(table.getSchemaName().getString().equals("SCHEMA2") &&
+                    table.getTableName().getString().equals(globalViewIdx));
+            assertTrue(rs.next());
+            assertEquals("b", rs.getString(1));
+            assertFalse(rs.next());
+            // Force a flush
+            flush(dataTable);
+            flush(indexTable);
+            assertRawRowCount(conn, dataTable, 1);
+            assertRawRowCount(conn, indexTable, 1);
+            // Delete the row from both tables
+            conn.createStatement().execute("DELETE FROM " + fullGlobalViewName
+                            + " WHERE TENANT_ID = 'TenantId1'");
+            conn.commit();
+            // Force a flush
+            flush(dataTable);
+            flush(indexTable);
+            assertRawRowCount(conn, dataTable, 1);
+            assertRawRowCount(conn, indexTable, 1);
+            // Move change beyond the max lookback window
+            injectEdge.setValue(System.currentTimeMillis() + MAX_LOOKBACK_AGE * 1000 + 1);
+            EnvironmentEdgeManager.injectEdge(injectEdge);
+            // Major compact both tables
+            majorCompact(dataTable);
+            majorCompact(indexTable);
+            // Everything should have been purged by major compaction
+            assertRawRowCount(conn, dataTable, 0);
+            assertRawRowCount(conn, indexTable, 0);
+        }
+    }
     @Test(timeout=60000L)
     public void testTTLAndMaxLookbackAge() throws Exception {
         Configuration conf = getUtility().getConfiguration();
@@ -318,7 +387,7 @@ public class MaxLookbackExtendedIT extends BaseTest {
             assertRawRowCount(conn, dataTable, originalRowCount);
             assertRawRowCount(conn, indexTable, originalRowCount);
             assertExplainPlan(conn, indexSql, dataTableName, indexName);
-            long timeToAdvance = (MAX_LOOKBACK_AGE * 1000) -
+            long timeToAdvance = (MAX_LOOKBACK_AGE * 1000L) -
                 (EnvironmentEdgeManager.currentTimeMillis() - afterFirstInsertSCN);
             if (timeToAdvance > 0) {
                 injectEdge.incrementValue(timeToAdvance);
@@ -333,7 +402,7 @@ public class MaxLookbackExtendedIT extends BaseTest {
             assertRawRowCount(conn, dataTable, originalRowCount);
             assertRawRowCount(conn, indexTable, originalRowCount);
             //now wait the TTL
-            timeToAdvance = (ttl * 1000) -
+            timeToAdvance = (ttl * 1000L) -
                 (EnvironmentEdgeManager.currentTimeMillis() - afterFirstInsertSCN);
             if (timeToAdvance > 0) {
                 injectEdge.incrementValue(timeToAdvance);
@@ -351,7 +420,7 @@ public class MaxLookbackExtendedIT extends BaseTest {
             Assert.assertEquals(0, rs.getInt(1));
             // Increment the time by max lookback age and make sure that we can compact away
             // the now-expired rows
-            injectEdge.incrementValue(MAX_LOOKBACK_AGE * 1000);
+            injectEdge.incrementValue(MAX_LOOKBACK_AGE * 1000L);
             majorCompact(dataTable);
             majorCompact(indexTable);
             assertRawRowCount(conn, dataTable, 0);
@@ -459,39 +528,94 @@ public class MaxLookbackExtendedIT extends BaseTest {
                 CompactionScanner.overrideMaxLookback(tableNameTwo, "A", maxLookbackTwo * 1000);
                 CompactionScanner.overrideMaxLookback(tableNameTwo, "B", maxLookbackTwo * 1000);
             }
-            injectEdge.incrementValue(1);
+            injectEdge.incrementValue(1000);
             populateTable(tableNameOne);
             populateTable(tableNameTwo);
-            injectEdge.incrementValue(1);
+            injectEdge.incrementValue(1000);
             populateTable(tableNameOne);
             populateTable(tableNameTwo);
-            injectEdge.incrementValue(1);
+            injectEdge.incrementValue(1000);
             conn.createStatement().executeUpdate("DELETE FROM " + tableNameOne);
             conn.createStatement().executeUpdate("DELETE FROM " + tableNameTwo);
             conn.commit();
-            injectEdge.incrementValue(1);
             // Move the time so that deleted row versions will be outside the maxlookback window
-            // of tableNameOne but the delete markers will be inside
+            // of tableNameOne but the delete markers will be inside (in this case on the lower
+            // edge of the window)
             injectEdge.incrementValue(maxLookbackOne * 1000);
-            // Compact both tables. Deleted row versions will be removed from tableNameOne as they
-            // are now outside its max lookback window.
+            // Compact both tables. Deleted row versions will be retained since the delete marker
+            // is retained. This is necessary to include the preimage of the row in the CDC
+            // stream.
             flush(TableName.valueOf(tableNameOne));
             flush(TableName.valueOf(tableNameTwo));
             majorCompact(TableName.valueOf(tableNameOne));
             majorCompact(TableName.valueOf(tableNameTwo));
             if (multiCF) {
-                assertRawCellCount(conn, TableName.valueOf(tableNameOne), Bytes.toBytes("a"), 3);
-                assertRawCellCount(conn, TableName.valueOf(tableNameOne), Bytes.toBytes("b"), 3);
+                assertRawCellCount(conn, TableName.valueOf(tableNameOne), Bytes.toBytes("a"), 7);
+                assertRawCellCount(conn, TableName.valueOf(tableNameOne), Bytes.toBytes("b"), 7);
                 assertRawCellCount(conn, TableName.valueOf(tableNameTwo), Bytes.toBytes("a"), 11);
                 assertRawCellCount(conn, TableName.valueOf(tableNameTwo), Bytes.toBytes("b"), 11);
             } else {
-                assertRawCellCount(conn, TableName.valueOf(tableNameOne), Bytes.toBytes("a"), 1);
-                assertRawCellCount(conn, TableName.valueOf(tableNameOne), Bytes.toBytes("b"), 1);
+                assertRawCellCount(conn, TableName.valueOf(tableNameOne), Bytes.toBytes("a"), 5);
+                assertRawCellCount(conn, TableName.valueOf(tableNameOne), Bytes.toBytes("b"), 5);
                 assertRawCellCount(conn, TableName.valueOf(tableNameTwo), Bytes.toBytes("a"), 9);
                 assertRawCellCount(conn, TableName.valueOf(tableNameTwo), Bytes.toBytes("b"), 9);
             }
         }
     }
+
+    @Test(timeout=60000)
+    public void testRetainingLastRowVersion() throws Exception {
+        try(Connection conn = DriverManager.getConnection(getUrl())) {
+            String tableName = generateUniqueName();
+            createTable(tableName);
+            long timeIntervalBetweenTwoUpserts = (ttl / 4) + 1;
+            injectEdge.setValue(System.currentTimeMillis());
+            EnvironmentEdgeManager.injectEdge(injectEdge);
+            TableName dataTableName = TableName.valueOf(tableName);
+            injectEdge.incrementValue(1);
+            Statement stmt = conn.createStatement();
+            stmt.execute("upsert into " + tableName + " values ('a', 'ab', 'abc', 'abcd')");
+            conn.commit();
+            injectEdge.incrementValue(timeIntervalBetweenTwoUpserts * 1000);
+            flush(dataTableName);
+            injectEdge.incrementValue(1);
+            stmt.execute("upsert into " + tableName + " values ('a', 'ab1')");
+            conn.commit();
+            injectEdge.incrementValue(timeIntervalBetweenTwoUpserts * 1000);
+            flush(dataTableName);
+            injectEdge.incrementValue(1);
+            stmt.execute("upsert into " + tableName + " values ('a', 'ab2')");
+            conn.commit();
+            injectEdge.incrementValue(timeIntervalBetweenTwoUpserts * 1000);
+            flush(dataTableName);
+            injectEdge.incrementValue(1);
+            TestUtil.minorCompact(utility, dataTableName);
+            injectEdge.incrementValue(1);
+            stmt.execute("upsert into " + tableName + " values ('a', 'ab3')");
+            conn.commit();
+            injectEdge.incrementValue(timeIntervalBetweenTwoUpserts * 1000);
+            flush(dataTableName);
+            injectEdge.incrementValue(1);
+            stmt.execute("upsert into " + tableName + " values ('a', 'ab4')");
+            conn.commit();
+            injectEdge.incrementValue(1);
+            flush(dataTableName);
+            TestUtil.dumpTable(conn, dataTableName);
+            injectEdge.incrementValue(1);
+            TestUtil.minorCompact(utility, dataTableName);
+            injectEdge.incrementValue(MAX_LOOKBACK_AGE * 1000 - 1);
+            TestUtil.dumpTable(conn, dataTableName);
+            majorCompact(dataTableName);
+            injectEdge.incrementValue(1);
+            TestUtil.dumpTable(conn, dataTableName);
+            ResultSet rs = stmt.executeQuery("select * from " + dataTableName + " where id = 'a'");
+            while(rs.next()) {
+                assertNotNull(rs.getString(3));
+                assertNotNull(rs.getString(4));
+            }
+        }
+    }
+
     private void flush(TableName table) throws IOException {
         Admin admin = getUtility().getAdmin();
         admin.flush(table);
