@@ -20,10 +20,12 @@ package org.apache.phoenix.end2end;
 import java.util.Collection;
 import java.util.List;
 
+import org.junit.experimental.categories.Category;
 import org.junit.runners.Parameterized.Parameters;
 
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
+@Category(ParallelStatsDisabledTest.class)
 public class NotQueryWithGlobalImmutableIndexesIT extends NotQueryIT {
 
     public NotQueryWithGlobalImmutableIndexesIT(String indexDDL, boolean columnEncoded, boolean keepDeleted) throws Exception {
