@@ -18,7 +18,9 @@
 package org.apache.phoenix.end2end;
 
 import org.junit.BeforeClass;
+import org.junit.experimental.categories.Category;
 
+@Category(NeedsOwnMiniClusterTest.class)
 public class PermissionNSDisabledIT extends BasePermissionsIT {
 
     public PermissionNSDisabledIT() throws Exception {
