@@ -46,10 +46,12 @@ import org.apache.phoenix.util.EncodedColumnsUtil;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.junit.Test;
+import org.junit.experimental.categories.Category;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
 
+@Category(ParallelStatsDisabledTest.class)
 @RunWith(Parameterized.class)
 public class RowTimestampIT extends ParallelStatsDisabledIT {
 
@@ -258,7 +260,7 @@ public class RowTimestampIT extends ParallelStatsDisabledIT {
             // the data in this query.
             PreparedStatement stmt =
                     conn.prepareStatement("SELECT KV1, KV2, PK2 FROM " + tableName
-                            + " WHERE PK1 = ? AND PK2 > ? AND PK2 < ? ");
+                            + " WHERE PK1 = ? AND PK2 >= ? AND PK2 <= ? ");
             stmt.setString(1, "PK1");
             stmt.setDate(2, new Date(startTime));
             stmt.setDate(3, new Date(endTime));
