@@ -23,6 +23,7 @@ import org.apache.hadoop.hbase.client.Admin;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.coprocessorclient.BaseScannerRegionObserverConstants;
 import org.apache.phoenix.query.BaseTest;
+import org.apache.phoenix.query.ConnectionQueryServices;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
@@ -52,6 +53,9 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Random;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+
 @Category(NeedsOwnMiniClusterTest.class)
 @RunWith(Parameterized.class)
 public class TableTTLIT extends BaseTest {
@@ -82,6 +86,7 @@ public class TableTTLIT extends BaseTest {
         Map<String, String> props = Maps.newHashMapWithExpectedSize(1);
         props.put(QueryServices.GLOBAL_INDEX_ROW_AGE_THRESHOLD_TO_DELETE_MS_ATTRIB, Long.toString(0));
         props.put(BaseScannerRegionObserverConstants.PHOENIX_MAX_LOOKBACK_AGE_CONF_KEY, Integer.toString(MAX_LOOKBACK_AGE));
+        props.put("hbase.procedure.remote.dispatcher.delay.msec", "0");
         setUpTestDriver(new ReadOnlyProps(props.entrySet().iterator()));
     }
 
@@ -148,29 +153,41 @@ public class TableTTLIT extends BaseTest {
     public void testMaskingAndCompaction() throws Exception {
         final int maxDeleteCounter = MAX_LOOKBACK_AGE;
         final int maxCompactionCounter = ttl / 2;
+        final int maxFlushCounter = ttl;
         final int maxMaskingCounter = 2 * ttl;
+        final int maxVerificationCounter = 2 * ttl;
         final byte[] rowKey = Bytes.toBytes("a");
         try (Connection conn = DriverManager.getConnection(getUrl())) {
             String tableName = generateUniqueName();
             createTable(tableName);
             String noCompactTableName = generateUniqueName();
             createTable(noCompactTableName);
+            conn.createStatement().execute("Alter Table " + noCompactTableName
+                    + " set \"phoenix.table.ttl.enabled\" = false");
+            conn.commit();
             long startTime = System.currentTimeMillis() + 1000;
             startTime = (startTime / 1000) * 1000;
             EnvironmentEdgeManager.injectEdge(injectEdge);
             injectEdge.setValue(startTime);
             int deleteCounter = RAND.nextInt(maxDeleteCounter) + 1;
             int compactionCounter = RAND.nextInt(maxCompactionCounter) + 1;
+            int flushCounter = RAND.nextInt(maxFlushCounter) + 1;
             int maskingCounter = RAND.nextInt(maxMaskingCounter) + 1;
-            boolean afterCompaction = false;
-            for (int i = 0; i < 500; i++) {
+            int verificationCounter = RAND.nextInt(maxVerificationCounter) + 1;
+            int maxIterationCount = multiCF ? 250 : 500;
+            for (int i = 0; i < maxIterationCount; i++) {
+                if (flushCounter-- == 0) {
+                    injectEdge.incrementValue(1000);
+                    LOG.info("Flush " + i + " current time: " + injectEdge.currentTime());
+                    flush(TableName.valueOf(tableName));
+                    flushCounter = RAND.nextInt(maxFlushCounter) + 1;
+                }
                 if (compactionCounter-- == 0) {
                     injectEdge.incrementValue(1000);
-                    LOG.debug("Compaction " + i + " current time: " + injectEdge.currentTime());
+                    LOG.info("Compaction " + i + " current time: " + injectEdge.currentTime());
                     flush(TableName.valueOf(tableName));
                     majorCompact(TableName.valueOf(tableName));
                     compactionCounter = RAND.nextInt(maxCompactionCounter) + 1;
-                    afterCompaction = true;
                 }
                 if (maskingCounter-- == 0) {
                     updateRow(conn, tableName, noCompactTableName, "a");
@@ -190,20 +207,18 @@ public class TableTTLIT extends BaseTest {
                     maskingCounter = RAND.nextInt(maxMaskingCounter) + 1;
                 }
                 if (deleteCounter-- == 0) {
-                    LOG.debug("Delete " + i + " current time: " + injectEdge.currentTime());
+                    LOG.info("Delete " + i + " current time: " + injectEdge.currentTime());
                     deleteRow(conn, tableName, "a");
                     deleteRow(conn, noCompactTableName, "a");
                     deleteCounter = RAND.nextInt(maxDeleteCounter) + 1;
                     injectEdge.incrementValue(1000);
                 }
+                injectEdge.incrementValue(1000);
                 updateRow(conn, tableName, noCompactTableName, "a");
-                if (!afterCompaction) {
-                    injectEdge.incrementValue(1000);
-                    // We are interested in the correctness of compaction and masking. Thus, we
-                    // only need to do the latest version and scn queries to after compaction.
+                if (verificationCounter-- >  0) {
                     continue;
                 }
-                afterCompaction = false;
+                verificationCounter = RAND.nextInt(maxVerificationCounter) + 1;
                 compareRow(conn, tableName, noCompactTableName, "a", MAX_COLUMN_INDEX);
                 long scn = injectEdge.currentTime() - MAX_LOOKBACK_AGE * 1000;
                 long scnEnd = injectEdge.currentTime();
@@ -217,11 +232,50 @@ public class TableTTLIT extends BaseTest {
                                 MAX_COLUMN_INDEX);
                     }
                 }
-                injectEdge.incrementValue(1000);
             }
         }
     }
 
+    @Test
+    public void testMinorCompactionShouldNotRetainCellsWhenMaxLookbackIsDisabled()
+            throws Exception {
+        try (Connection conn = DriverManager.getConnection(getUrl())) {
+            String tableName = generateUniqueName();
+            createTable(tableName);
+            conn.createStatement().execute("Alter Table " + tableName + " set \"phoenix.max.lookback.age.seconds\" = 0");
+            conn.commit();
+            final int flushCount = 10;
+            byte[] row = Bytes.toBytes("a");
+            int rowUpdateCounter = 0;
+            injectEdge.setValue(System.currentTimeMillis());
+            EnvironmentEdgeManager.injectEdge(injectEdge);
+            injectEdge.incrementValue(1);
+            for (int i = 0; i < flushCount; i++) {
+                // Generate more row versions than the maximum cell versions for the table
+                int updateCount = RAND.nextInt(10) + versions;
+                rowUpdateCounter += updateCount;
+                for (int j = 0; j < updateCount; j++) {
+                    updateRow(conn, tableName, "a");
+                    injectEdge.incrementValue(1);
+                }
+                flush(TableName.valueOf(tableName));
+                injectEdge.incrementValue(1);
+                // Flushes dump and retain all the cells to HFile.
+                // Doing MAX_COLUMN_INDEX + 1 to account for empty cells
+                assertEquals(TestUtil.getRawCellCount(conn, TableName.valueOf(tableName), row),
+                        rowUpdateCounter * (MAX_COLUMN_INDEX + 1));
+            }
+            TestUtil.dumpTable(conn, TableName.valueOf(tableName));
+            // Run one minor compaction (in case no minor compaction has happened yet)
+            TestUtil.minorCompact(utility, TableName.valueOf(tableName));
+            injectEdge.incrementValue(1);
+            TestUtil.dumpTable(conn, TableName.valueOf(tableName));
+            // For multi-CF table we retain all empty cells during minor compaction
+            int retainedCellCount = (MAX_COLUMN_INDEX + 1) * versions + (multiCF ? rowUpdateCounter - versions : 0);
+            assertEquals(retainedCellCount, TestUtil.getRawCellCount(conn, TableName.valueOf(tableName), Bytes.toBytes("a")));
+        }
+    }
+
     @Test
     public void testRowSpansMultipleTTLWindows() throws Exception {
         try (Connection conn = DriverManager.getConnection(getUrl())) {
@@ -291,6 +345,16 @@ public class TableTTLIT extends BaseTest {
         conn.commit();
     }
 
+    private void updateRow(Connection conn, String tableName, String id)
+            throws SQLException {
+
+        for (int i = 1; i <= MAX_COLUMN_INDEX; i++) {
+            String value = Integer.toString(RAND.nextInt(1000));
+            updateColumn(conn, tableName, id, i, value);
+        }
+        conn.commit();
+    }
+
     private void compareRow(Connection conn, String tableName1, String tableName2, String id,
             int maxColumnIndex) throws SQLException, IOException {
         StringBuilder queryBuilder = new StringBuilder("SELECT ");
