@@ -52,8 +52,7 @@ public class TransactionalViewIT extends ParallelStatsEnabledIT {
     
     @Parameters(name="TransactionalViewIT_transactionProvider={0}")
     public static synchronized Collection<Object[]> data() {
-        return TestUtil.filterTxParamData(Arrays.asList(new Object[][] { 
-                 {"TEPHRA"},{"OMID"}}),0);
+        return Arrays.asList(new Object[][] { { "OMID" } });
     }
     
     @Before
