@@ -18,10 +18,13 @@
 package org.apache.phoenix.end2end;
 
 import static org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder.KEEP_DELETED_CELLS;
+import static org.apache.phoenix.query.QueryServicesOptions.DEFAULT_TIMEOUT_DURING_UPGRADE_MS;
+import static org.apache.phoenix.thirdparty.com.google.common.base.Preconditions.checkNotNull;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.COLUMN_FAMILY;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.COLUMN_NAME;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.LAST_DDL_TIMESTAMP;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CATALOG_NAME;
+import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CHILD_LINK_NAME;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.SYSTEM_CATALOG_TABLE;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_NAME;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_SCHEM;
@@ -29,7 +32,6 @@ import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TABLE_TYPE;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.TENANT_ID;
 import static org.apache.phoenix.jdbc.PhoenixDatabaseMetaData.VIEW_INDEX_ID;
 import static org.apache.phoenix.query.QueryConstants.SYSTEM_SCHEMA_NAME;
-import static org.apache.phoenix.thirdparty.com.google.common.base.Preconditions.checkNotNull;
 import static org.junit.Assert.assertArrayEquals;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
@@ -47,7 +49,9 @@ import java.sql.SQLException;
 import java.sql.Statement;
 import java.sql.Types;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
+import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 import java.util.concurrent.Callable;
@@ -58,6 +62,10 @@ import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicInteger;
 
+import org.apache.hadoop.hbase.HConstants;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
+import org.apache.phoenix.thirdparty.com.google.common.util.concurrent.ThreadFactoryBuilder;
 import org.apache.hadoop.hbase.Cell;
 import org.apache.hadoop.hbase.CellUtil;
 import org.apache.hadoop.hbase.HConstants;
@@ -73,9 +81,7 @@ import org.apache.hadoop.hbase.client.Table;
 import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.phoenix.schema.types.PInteger;
-import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
-import org.apache.phoenix.thirdparty.com.google.common.collect.Sets;
-import org.apache.phoenix.coprocessor.MetaDataProtocol;
+import org.apache.phoenix.coprocessorclient.MetaDataProtocol;
 import org.apache.phoenix.exception.UpgradeInProgressException;
 import org.apache.phoenix.exception.UpgradeRequiredException;
 import org.apache.phoenix.jdbc.PhoenixConnection;
@@ -92,7 +98,6 @@ import org.apache.phoenix.schema.PTable.LinkType;
 import org.apache.phoenix.schema.PTableType;
 import org.apache.phoenix.schema.SequenceAllocation;
 import org.apache.phoenix.schema.SequenceKey;
-import org.apache.phoenix.thirdparty.com.google.common.util.concurrent.ThreadFactoryBuilder;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
 import org.apache.phoenix.util.MetaDataUtil;
 import org.apache.phoenix.util.PhoenixRuntime;
@@ -295,7 +300,8 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
         return DriverManager.getConnection(getUrl(), props);
     }
 
-    private Connection getConnection(boolean tenantSpecific, String tenantId, boolean isNamespaceMappingEnabled)
+    private Connection getConnection(boolean tenantSpecific, String tenantId,
+            boolean isNamespaceMappingEnabled, boolean copyChildLinksDuringUpgrade)
         throws SQLException {
         if (tenantSpecific) {
             checkNotNull(tenantId);
@@ -305,14 +311,26 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
         if (isNamespaceMappingEnabled){
             props.setProperty(QueryServices.IS_NAMESPACE_MAPPING_ENABLED, "true");
         }
+        if (copyChildLinksDuringUpgrade){
+            props.setProperty(QueryServices.MOVE_CHILD_LINKS_DURING_UPGRADE_ENABLED, "false");
+        }
         return DriverManager.getConnection(getUrl(), props);
     }
     private Connection getConnection(boolean tenantSpecific, String tenantId) throws SQLException {
-        return getConnection(tenantSpecific, tenantId, false);
+        return getConnection(tenantSpecific, tenantId, false, false);
     }
     
     @Test
     public void testMoveParentChildLinks() throws Exception {
+        testParentChildLinksHelper(false);
+    }
+
+    @Test
+    public void testCopyParentChildLinks() throws Exception {
+        testParentChildLinksHelper(true);
+    }
+
+    private void testParentChildLinksHelper(boolean copyMode) throws Exception {
         String schema = "S_" + generateUniqueName();
         String table1 = "T_" + generateUniqueName();
         String table2 = "T_" + generateUniqueName();
@@ -324,7 +342,7 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
         String viewIndexName2 = "VIDX_" + generateUniqueName();
         try (Connection conn = getConnection(false, null);
                 Connection tenantConn = getConnection(true, "tenant1");
-                Connection metaConn = getConnection(false, null)) {
+                Connection metaConn = getConnection(false, null, false, copyMode)) {
             // create a non multi-tenant and multi-tenant table
             conn.createStatement()
                     .execute("CREATE TABLE IF NOT EXISTS " + tableName + " ("
@@ -349,7 +367,7 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
                     .execute("create index " + viewIndexName2 + " on " + viewName2 + "(col)");
 
             // query all parent -> child links
-            Set<String> expectedChildLinkSet = getChildLinks(conn);
+            Set<String> expectedChildLinkSet = getChildLinks(conn, SYSTEM_CHILD_LINK_NAME);
 
             // delete all the child links
             conn.createStatement().execute("DELETE FROM SYSTEM.CHILD_LINK WHERE LINK_TYPE = "
@@ -360,11 +378,29 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
             phxMetaConn.setRunningUpgrade(true);
             // create the parent-> child links in SYSTEM.CATALOG
             UpgradeUtil.addParentToChildLinks(phxMetaConn);
+
+            // Increase the timeouts so that the scan queries during moveOrCopyChildLinks do not timeout on large syscat's
+            Map<String, String> options = new HashMap<>();
+            options.put(HConstants.HBASE_RPC_TIMEOUT_KEY, Integer.toString(DEFAULT_TIMEOUT_DURING_UPGRADE_MS));
+            options.put(HConstants.HBASE_CLIENT_SCANNER_TIMEOUT_PERIOD, Integer.toString(DEFAULT_TIMEOUT_DURING_UPGRADE_MS));
+            String clientPort = getUtility().getConfiguration().get(QueryServices.ZOOKEEPER_PORT_ATTRIB);
+
+            String localQuorum = String.format("localhost:%s", clientPort);
+            options.put(QueryServices.ZOOKEEPER_QUORUM_ATTRIB, localQuorum);
+            options.put(QueryServices.ZOOKEEPER_PORT_ATTRIB, clientPort);
+
+
             // move the parent->child links to SYSTEM.CHILD_LINK
-            UpgradeUtil.moveChildLinks(phxMetaConn);
-            Set<String> actualChildLinkSet = getChildLinks(conn);
+            UpgradeUtil.moveOrCopyChildLinks(phxMetaConn, options);
+            Set<String> actualChildLinkSet = getChildLinks(conn, SYSTEM_CHILD_LINK_NAME);
+            Set<String> actualChildLinkInSyscatSet = getChildLinks(conn, SYSTEM_CATALOG_NAME);
 
             assertEquals("Unexpected child links", expectedChildLinkSet, actualChildLinkSet);
+            if (copyMode) {
+                assertEquals("Unexpected child links in catalog", expectedChildLinkSet, actualChildLinkInSyscatSet);
+            } else {
+                assertEquals("Unexpected child links in catalog", new HashSet<String>(), actualChildLinkInSyscatSet);
+            }
         }
     }
 
@@ -384,7 +420,7 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
                     HConstants.VERSIONS + "='1000'\n");
         }
         //Check that the HBase tables reflect the change
-        PTable sysLogTable = PhoenixRuntime.getTable(conn, PhoenixDatabaseMetaData.SYSTEM_LOG_NAME);
+        PTable sysLogTable = conn.getTable(PhoenixDatabaseMetaData.SYSTEM_LOG_NAME);
         TableDescriptor sysLogDesc = utility.getAdmin().getDescriptor(SchemaUtil.getPhysicalTableName(
             PhoenixDatabaseMetaData.SYSTEM_LOG_NAME, cqs.getProps()));
         assertEquals(KeepDeletedCells.TRUE, sysLogDesc.getColumnFamily(
@@ -392,7 +428,7 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
         assertEquals(1000, sysLogDesc.getColumnFamily(
                 SchemaUtil.getEmptyColumnFamily(sysLogTable)).getMaxVersions());
 
-        PTable sysStatsTable = PhoenixRuntime.getTable(conn, PhoenixDatabaseMetaData.SYSTEM_STATS_NAME);
+        PTable sysStatsTable = conn.getTable(PhoenixDatabaseMetaData.SYSTEM_STATS_NAME);
         TableDescriptor sysStatsDesc = utility.getAdmin().getDescriptor(SchemaUtil.getPhysicalTableName(
             PhoenixDatabaseMetaData.SYSTEM_STATS_NAME, cqs.getProps()));
         assertEquals(KeepDeletedCells.TRUE, sysStatsDesc.getColumnFamily(
@@ -474,11 +510,11 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
         assertEquals(Boolean.TRUE, updatedCFD.isCacheIndexesOnWrite());
     }
 
-    private Set<String> getChildLinks(Connection conn) throws SQLException {
+    private Set<String> getChildLinks(Connection conn, String tableName) throws SQLException {
         ResultSet rs =
-                conn.createStatement().executeQuery(
-                    "SELECT TENANT_ID, TABLE_SCHEM, TABLE_NAME, COLUMN_NAME, COLUMN_FAMILY FROM SYSTEM.CHILD_LINK WHERE LINK_TYPE = "
-                            + LinkType.CHILD_TABLE.getSerializedValue());
+                conn.createStatement().executeQuery(String.format(
+                    "SELECT TENANT_ID, TABLE_SCHEM, TABLE_NAME, COLUMN_NAME, COLUMN_FAMILY FROM %s WHERE LINK_TYPE = %d",
+                            tableName, LinkType.CHILD_TABLE.getSerializedValue()));
         Set<String> childLinkSet = Sets.newHashSet();
         while (rs.next()) {
             String key =
@@ -501,7 +537,7 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
     }
 
     private void testMergeViewIndexSequencesHelper(boolean isNamespaceMappingEnabled) throws Exception {
-        PhoenixConnection conn = getConnection(false, null, isNamespaceMappingEnabled).unwrap(PhoenixConnection.class);
+        PhoenixConnection conn = getConnection(false, null, isNamespaceMappingEnabled, false).unwrap(PhoenixConnection.class);
         ConnectionQueryServices cqs = conn.getQueryServices();
         //First delete any sequences that may exist from previous tests
         conn.createStatement().execute("DELETE FROM " + PhoenixDatabaseMetaData.SYSTEM_SEQUENCE);
@@ -643,10 +679,12 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
 
     @Test
     public void testLastDDLTimestampBootstrap() throws Exception {
+        Long testStartTime = EnvironmentEdgeManager.currentTimeMillis();
         //Create a table, view, and index
         String schemaName = "S_" + generateUniqueName();
         String tableName = "T_" + generateUniqueName();
         String viewName = "V_" + generateUniqueName();
+        String indexName = "I_" + generateUniqueName();
         String fullTableName = SchemaUtil.getTableName(schemaName, tableName);
         String fullViewName = SchemaUtil.getTableName(schemaName, viewName);
         try (Connection conn = getConnection(false, null)) {
@@ -657,6 +695,8 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
             conn.createStatement().execute(
                 "CREATE VIEW " + fullViewName + " AS SELECT * FROM " + fullTableName);
 
+            conn.createStatement().execute("CREATE INDEX " + indexName + " ON " + fullTableName + " (KV1) ASYNC");
+
             //Now we null out any existing last ddl timestamps
             nullDDLTimestamps(conn);
 
@@ -664,14 +704,28 @@ public class UpgradeIT extends ParallelStatsDisabledIT {
             long tableTS = getRowTimestampForMetadata(conn, schemaName, tableName,
                 PTableType.TABLE);
             long viewTS = getRowTimestampForMetadata(conn, schemaName, viewName, PTableType.VIEW);
+            long indexTS = getRowTimestampForMetadata(conn, schemaName, indexName, PTableType.INDEX);
+            assertTrue(tableTS > testStartTime);
+            assertTrue(viewTS > testStartTime);
+            assertTrue(indexTS > testStartTime);
 
-            UpgradeUtil.bootstrapLastDDLTimestamp(conn.unwrap(PhoenixConnection.class));
+            // bootstrap last ddl timestamp for tables and views
+            UpgradeUtil.bootstrapLastDDLTimestampForTablesAndViews(conn.unwrap(PhoenixConnection.class));
             long actualTableTS = getLastTimestampForMetadata(conn, schemaName, tableName,
                 PTableType.TABLE);
             long actualViewTS = getLastTimestampForMetadata(conn, schemaName, viewName,
                 PTableType.VIEW);
+            long actualIndexTS = getLastTimestampForMetadata(conn, schemaName, indexName,
+                    PTableType.INDEX);
             assertEquals(tableTS, actualTableTS);
             assertEquals(viewTS, actualViewTS);
+            // only tables and views were bootstrapped
+            assertEquals(0L, actualIndexTS);
+
+            // bootstrap last ddl timestamp for indexes
+            UpgradeUtil.bootstrapLastDDLTimestampForIndexes(conn.unwrap(PhoenixConnection.class));
+            actualIndexTS = getLastTimestampForMetadata(conn, schemaName, indexName, PTableType.INDEX);
+            assertEquals(indexTS, actualIndexTS);
 
         }
     }
