@@ -57,6 +57,7 @@ import org.apache.phoenix.coprocessor.PhoenixMetaDataCoprocessorHost
         .PhoenixMetaDataControllerEnvironment;
 import org.apache.phoenix.exception.PhoenixIOException;
 import org.apache.phoenix.exception.SQLExceptionCode;
+import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.schema.ConcurrentTableMutationException;
 import org.apache.phoenix.schema.PTable;
@@ -67,7 +68,6 @@ import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.PropertiesUtil;
 import org.apache.phoenix.util.ReadOnlyProps;
 import org.apache.phoenix.util.SchemaUtil;
-import org.apache.phoenix.util.TestUtil;
 import org.junit.After;
 import org.junit.BeforeClass;
 import org.junit.Test;
@@ -120,10 +120,10 @@ public class ViewConcurrencyAndFailureIT extends SplitSystemCatalogIT {
     @Parameters(name="ViewConcurrencyAndFailureIT_transactionProvider={0}, "
             + "columnEncoded={1}")
     public static synchronized Collection<Object[]> data() {
-        return TestUtil.filterTxParamData(Arrays.asList(new Object[][] {
-                { "TEPHRA", false }, { "TEPHRA", true },
-                { "OMID", false },
-                { null, false }, { null, true }}),0);
+        return Arrays.asList(new Object[][] {
+            // OMID does not support column encoding
+            { "OMID", false },
+            { null, false }, { null, true }});
     }
 
     @BeforeClass
@@ -157,7 +157,7 @@ public class ViewConcurrencyAndFailureIT extends SplitSystemCatalogIT {
 
     @Test
     public void testChildViewCreationFails() throws Exception {
-        try (Connection conn = DriverManager.getConnection(getUrl());
+        try (PhoenixConnection conn = (PhoenixConnection) DriverManager.getConnection(getUrl());
                 Statement stmt = conn.createStatement()) {
 
             String fullTableName = SchemaUtil.getTableName(SCHEMA1,
@@ -186,15 +186,15 @@ public class ViewConcurrencyAndFailureIT extends SplitSystemCatalogIT {
 
             // the first child view should not exist
             try {
-                PhoenixRuntime.getTableNoCache(conn, failingViewName);
+                conn.getTableNoCache(failingViewName);
                 fail();
             } catch (TableNotFoundException ignored) {
             }
 
             // we should be able to load the table
-            PhoenixRuntime.getTableNoCache(conn, fullTableName);
+            conn.getTableNoCache(fullTableName);
             // we should be able to load the second view
-            PhoenixRuntime.getTableNoCache(conn, succeedingViewName);
+            conn.getTableNoCache(succeedingViewName);
         }
     }
 
