@@ -44,27 +44,39 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 
+import org.apache.hadoop.hbase.HBaseTestingUtility;
+import org.apache.hadoop.hbase.NamespaceDescriptor;
+import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptorBuilder;
 import org.apache.hadoop.hbase.client.Scan;
+import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.util.Pair;
 import org.apache.phoenix.compile.ExplainPlan;
 import org.apache.phoenix.compile.ExplainPlanAttributes;
 import org.apache.phoenix.compile.QueryPlan;
 import org.apache.phoenix.exception.SQLExceptionCode;
+import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.jdbc.PhoenixPreparedStatement;
 import org.apache.phoenix.jdbc.PhoenixStatement;
 import org.apache.phoenix.query.KeyRange;
 import org.apache.phoenix.query.QueryServices;
 import org.apache.phoenix.schema.PTable;
+import org.apache.phoenix.schema.PTableImpl;
 import org.apache.phoenix.schema.ReadOnlyTableException;
+import org.apache.phoenix.schema.ColumnNotFoundException;
+import org.apache.phoenix.schema.SchemaNotFoundException;
+import org.apache.phoenix.schema.TableNotFoundException;
+import org.apache.phoenix.schema.TableAlreadyExistsException;
+import org.apache.phoenix.schema.export.DefaultSchemaRegistryRepository;
+import org.apache.phoenix.schema.export.DefaultSchemaWriter;
+import org.apache.phoenix.schema.export.SchemaRegistryRepository;
+import org.apache.phoenix.schema.export.SchemaRegistryRepositoryFactory;
+import org.apache.phoenix.schema.types.PVarbinary;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 import org.apache.phoenix.transaction.PhoenixTransactionProvider.Feature;
 import org.apache.phoenix.transaction.TransactionFactory;
-import org.apache.phoenix.util.EnvironmentEdgeManager;
-import org.apache.phoenix.util.MetaDataUtil;
-import org.apache.phoenix.util.PhoenixRuntime;
-import org.apache.phoenix.util.ReadOnlyProps;
-import org.apache.phoenix.util.SchemaUtil;
-import org.apache.phoenix.util.TestUtil;
+import org.apache.phoenix.util.*;
 import org.junit.BeforeClass;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
@@ -72,6 +84,7 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
 
+
 import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 
 /**
@@ -105,10 +118,10 @@ public class ViewIT extends SplitSystemCatalogIT {
     // name is used by failsafe as file name in reports
     @Parameters(name="ViewIT_transactionProvider={0}, columnEncoded={1}")
     public static synchronized Collection<Object[]> data() {
-        return TestUtil.filterTxParamData(Arrays.asList(new Object[][] { 
-            { "TEPHRA", false }, { "TEPHRA", true },
-            { "OMID", false }, 
-            { null, false }, { null, true }}),0);
+        return Arrays.asList(new Object[][] {
+            // OMID does not support column encoding
+            { "OMID", false },
+            { null, false }, { null, true }});
     }
     
     @BeforeClass
@@ -269,7 +282,46 @@ public class ViewIT extends SplitSystemCatalogIT {
             assertEquals(4, count);
         }
     }
-    
+
+    @Test
+    public void testCreateMappedViewWithHbaseNamespace() throws Exception {
+        Properties props = new Properties();
+        props.setProperty(QueryServices.IS_NAMESPACE_MAPPING_ENABLED,
+                Boolean.TRUE.toString());
+        Connection conn1 = DriverManager.getConnection(getUrl(), props);
+        conn1.setAutoCommit(true);
+
+        HBaseTestingUtility testUtil = getUtility();
+        Admin admin = testUtil.getAdmin();
+
+        String nameSpace = generateUniqueName();
+        admin.createNamespace(NamespaceDescriptor.create(nameSpace).build());
+
+        String tableNameStr = generateUniqueName();
+        TableName tableName = TableName.valueOf(nameSpace, tableNameStr);
+        String familyNameStr = "colFam1";
+        TableDescriptorBuilder builder = TableDescriptorBuilder.newBuilder(tableName);
+        builder.setColumnFamily(ColumnFamilyDescriptorBuilder.of(
+                familyNameStr));
+        admin.createTable(builder.build());
+
+
+        String viewName = SchemaUtil.getTableName(nameSpace, tableNameStr);
+        try {
+            conn1.createStatement().execute("CREATE VIEW " + viewName +
+                    " (pk VARCHAR PRIMARY KEY, \"colFam1\".\"lastname\" VARCHAR )");
+        } catch (SchemaNotFoundException e) {
+            assertEquals(nameSpace, e.getSchemaName());
+            assertEquals("ERROR 722 (43M05): Schema does not exist schemaName="
+                            + nameSpace,
+                    e.getMessage());
+        }
+
+        conn1.createStatement().execute("CREATE SCHEMA IF NOT EXISTS " + nameSpace);
+        conn1.createStatement().execute("CREATE VIEW " + viewName +
+                " (pk VARCHAR PRIMARY KEY, \"colFam1\".\"lastname\" VARCHAR )");
+    }
+
     @Test
     public void testViewWithCurrentDate() throws Exception {
         try (Connection conn = DriverManager.getConnection(getUrl());
@@ -326,6 +378,78 @@ public class ViewIT extends SplitSystemCatalogIT {
         }
     }
 
+    @Test
+    public void testCreateViewSchemaVersion() throws Exception {
+        Properties props = new Properties();
+        final String schemaName = generateUniqueName();
+        final String tableName = generateUniqueName();
+        final String viewName = generateUniqueName();
+        final String dataTableFullName = SchemaUtil.getTableName(schemaName, tableName);
+        final String viewFullName = SchemaUtil.getTableName(schemaName, viewName);
+        try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
+            String version = "V1.0";
+            String topicName = "MyTopicName";
+            CreateTableIT.testCreateTableSchemaVersionAndTopicNameHelper(conn, schemaName,
+                tableName, version, topicName);
+            String createViewSql = "CREATE VIEW " + viewFullName + " AS SELECT * FROM " + dataTableFullName +
+                    " SCHEMA_VERSION='" + version + "', STREAMING_TOPIC_NAME='" + topicName + "'";
+            conn.createStatement().execute(createViewSql);
+            PTable view = conn.unwrap(PhoenixConnection.class).getTableNoCache(viewFullName);
+            assertEquals(version, view.getSchemaVersion());
+            assertEquals(topicName, view.getStreamingTopicName());
+        }
+    }
+
+    @Test
+    public void testCreateViewsWithChangeDetectionEnabled() throws Exception {
+        String tenantId = "T_" + generateUniqueName();
+        String schemaName = "S_" + generateUniqueName();
+        String tableName = "T_" + generateUniqueName();
+        String globalViewName = "GV_" + generateUniqueName();
+        String tenantViewName = "TV_" + generateUniqueName();
+        String fullTableName = SchemaUtil.getTableName(schemaName, tableName);
+        String fullGlobalViewName = SchemaUtil.getTableName(schemaName, globalViewName);
+        String fullTenantViewName = SchemaUtil.getTableName(schemaName, tenantViewName);
+
+        PTable globalView = null;
+        try (PhoenixConnection conn = (PhoenixConnection) DriverManager.getConnection(getUrl())) {
+            String ddl = "CREATE TABLE " + fullTableName +
+                " (id char(1) NOT NULL," + " col1 integer NOT NULL," + " col2 bigint NOT NULL," +
+                " CONSTRAINT NAME_PK PRIMARY KEY (id, col1, col2)) " +
+                "MULTI_TENANT=true, CHANGE_DETECTION_ENABLED=true";
+            conn.createStatement().execute(ddl);
+            PTable table = conn.getTableNoCache(fullTableName);
+            assertTrue(table.isChangeDetectionEnabled());
+            AlterTableIT.verifySchemaExport(table, getUtility().getConfiguration());
+
+            String globalViewDdl = "CREATE VIEW " + fullGlobalViewName +
+                " (id2 CHAR(12) PRIMARY KEY, col3 BIGINT NULL) " +
+                " AS SELECT * FROM " + fullTableName + " CHANGE_DETECTION_ENABLED=true";
+
+            conn.createStatement().execute(globalViewDdl);
+            globalView = conn.getTableNoCache(fullGlobalViewName);
+            assertTrue(globalView.isChangeDetectionEnabled());
+            PTable globalViewWithParents = ViewUtil.addDerivedColumnsFromParent(conn, globalView, table);
+            //   base column count doesn't get set properly
+            PTableImpl.Builder builder = PTableImpl.builderFromExisting(globalViewWithParents);
+            builder.setBaseColumnCount(table.getColumns().size());
+            globalViewWithParents = builder.setColumns(globalViewWithParents.getColumns()).build();
+            AlterTableIT.verifySchemaExport(globalViewWithParents, getUtility().getConfiguration());
+        }
+        Properties props = new Properties();
+        props.setProperty(PhoenixRuntime.TENANT_ID_ATTRIB, tenantId);
+        try (PhoenixConnection tenantConn = (PhoenixConnection) DriverManager.getConnection(getUrl(), props)) {
+            String tenantViewDdl = "CREATE VIEW " + fullTenantViewName +
+                " (id3 VARCHAR PRIMARY KEY, col4 VARCHAR NULL) " +
+                " AS SELECT * FROM " + fullGlobalViewName + " CHANGE_DETECTION_ENABLED=true";
+            tenantConn.createStatement().execute(tenantViewDdl);
+            PTable tenantView = tenantConn.getTableNoCache(fullTenantViewName);
+            assertTrue(tenantView.isChangeDetectionEnabled());
+            PTable tenantViewWithParents = ViewUtil.addDerivedColumnsFromParent(tenantConn, tenantView, globalView);
+            AlterTableIT.verifySchemaExport(tenantViewWithParents, getUtility().getConfiguration());
+        }
+    }
+
     @Test
     public void testCreateViewTimestamp() throws Exception {
         String tenantId = null;
@@ -366,6 +490,37 @@ public class ViewIT extends SplitSystemCatalogIT {
         }
     }
 
+    @Test
+    public void testCreateChangeDetectionEnabledTable() throws Exception {
+        //create a view with CHANGE_DETECTION_ENABLED and verify both that it's set properly
+        //on the PTable, and that it gets persisted to the external schema registry
+
+        String schemaName = generateUniqueName();
+        String tableName = generateUniqueName();
+        String fullTableName = SchemaUtil.getTableName(schemaName, tableName);
+        String viewName = generateUniqueName();
+        String fullViewName = SchemaUtil.getTableName(schemaName, viewName);
+        try (Connection conn = DriverManager.getConnection(getUrl())) {
+            String ddl = "CREATE TABLE " + fullTableName +
+                " (id char(1) NOT NULL," + " col1 integer NOT NULL," + " col2 bigint NOT NULL," +
+                " CONSTRAINT NAME_PK PRIMARY KEY (id, col1, col2)) " +
+                "CHANGE_DETECTION_ENABLED=true";
+            conn.createStatement().execute(ddl);
+
+            String viewDdl = "CREATE VIEW " + fullViewName + " AS SELECT * FROM " + fullTableName
+                + " CHANGE_DETECTION_ENABLED=true";
+            conn.createStatement().execute(viewDdl);
+            PTable view = conn.unwrap(PhoenixConnection.class).getTableNoCache(fullViewName);
+            assertTrue(view.isChangeDetectionEnabled());
+            assertEquals(DefaultSchemaRegistryRepository.getSchemaId(view),
+                view.getExternalSchemaId());
+            String schemaText = new DefaultSchemaWriter().exportSchema(view);
+            SchemaRegistryRepository repo = SchemaRegistryRepositoryFactory.getSchemaRegistryRepository(
+                getUtility().getConfiguration());
+            //assertEquals(schemaText, repo.getSchemaById(view.getExternalSchemaId()));
+        }
+    }
+
     private void testViewUsesTableIndex(boolean localIndex) throws Exception {
         ResultSet rs;
         // Use unique name for table with local index as otherwise we run
@@ -438,7 +593,8 @@ public class ViewIT extends SplitSystemCatalogIT {
             // Assert that in either case (local & global) that index from
             // physical table used for query on view.
             if (localIndex) {
-                assertEquals(fullTableName, explainPlanAttributes.getTableName());
+                assertEquals(fullIndexName1 + "(" + fullTableName + ")",
+                        explainPlanAttributes.getTableName());
                 assertEquals(" [1,1,100] - [1,2,109]",
                     explainPlanAttributes.getKeyRanges());
                 assertEquals("CLIENT MERGE SORT",
@@ -505,9 +661,9 @@ public class ViewIT extends SplitSystemCatalogIT {
             } catch (Exception ignore) {
             }
             // Check view inherits index, but child view doesn't
-            PTable table = PhoenixRuntime.getTable(conn, fullViewName);
+            PTable table = conn.unwrap(PhoenixConnection.class).getTable(fullViewName);
             assertEquals(1, table.getIndexes().size());
-            table = PhoenixRuntime.getTable(conn, fullChildViewName);
+            table = conn.unwrap(PhoenixConnection.class).getTable(fullChildViewName);
             assertEquals(0, table.getIndexes().size());
 
             ResultSet rs = stmt.executeQuery("select count(*) from "
@@ -538,7 +694,6 @@ public class ViewIT extends SplitSystemCatalogIT {
                     + "PRIMARY KEY) "
                     + "AS SELECT * FROM " + fullTableName + " WHERE K1 = 1";
             stmt.execute(ddl);
-
             // assert PK metadata
             ResultSet rs = conn.getMetaData().getPrimaryKeys(null,
                     SchemaUtil.getSchemaNameFromFullName(fullViewName),
@@ -790,6 +945,67 @@ public class ViewIT extends SplitSystemCatalogIT {
         }
     }
 
+    @Test
+    //creating view with same name on top of a table with a non existent column
+    public void testCreateViewWithUndefinedSameColumnName() throws Exception {
+        String fullViewName = generateUniqueName();
+
+        try (Connection conn = DriverManager.getConnection(getUrl());
+             Statement stmt = conn.createStatement()) {
+            String ddl = "CREATE VIEW " + fullViewName +
+                    " AS SELECT * FROM " + fullViewName +
+                    " WHERE " + fullViewName + " = 1";
+            stmt.execute(ddl);
+            fail("Should have thrown an exception");
+        } catch (ColumnNotFoundException columnException) {
+            assertEquals("Undefined column",
+                    SQLExceptionCode.COLUMN_NOT_FOUND
+                    .getErrorCode(), columnException.getErrorCode());
+            assertEquals(fullViewName, columnException.getColumnName());
+        }
+    }
+
+    @Test
+    //creating view with same name on top of a non existent table
+    public void testCreateViewOnTopOfUndefinedTableWithSameName() throws Exception {
+        try (Connection conn = DriverManager.getConnection(getUrl());
+             Statement stmt = conn.createStatement()) {
+
+            String fullViewName = generateUniqueName();
+            String ddl = "CREATE VIEW " +  fullViewName +
+                    " AS SELECT * FROM " + fullViewName;
+            stmt.execute(ddl);
+            fail("Should have thrown an exception");
+        } catch (TableNotFoundException tableException) {
+            assertEquals("Table Undefined",
+                    SQLExceptionCode.TABLE_UNDEFINED.getErrorCode(),
+                    tableException.getErrorCode());
+        }
+    }
+
+    @Test
+    //creating view with same name as the parent table
+    public void testCreateViewOnTopOfTableWithSameName() throws Exception {
+        try (Connection conn = DriverManager.getConnection(getUrl());
+             Statement stmt = conn.createStatement()) {
+
+            String fullTableName = generateUniqueName();
+            String ddl = "CREATE TABLE " + fullTableName
+                    + " (k1 INTEGER NOT NULL, k2 INTEGER NOT NULL, v1 DECIMAL, "
+                    + "CONSTRAINT pk PRIMARY KEY (k1, k2))" + tableDDLOptions;
+            stmt.execute(ddl);
+
+            ddl = "CREATE VIEW " + fullTableName + "(v2 VARCHAR, k3 VARCHAR "
+                    + "PRIMARY KEY) "
+                    + "AS SELECT * FROM " + fullTableName + " WHERE K1 = 1";
+            stmt.execute(ddl);
+            fail("Should have thrown an exception");
+        } catch (TableAlreadyExistsException tableException) {
+            assertEquals("Table already exists",
+                    SQLExceptionCode.TABLE_ALREADY_EXIST
+                    .getErrorCode(), tableException.getErrorCode());
+        }
+    }
     private void validate(String viewName, Connection tenantConn,
             String[] whereClauseArray,
             long[] expectedArray) throws SQLException {
@@ -916,6 +1132,8 @@ public class ViewIT extends SplitSystemCatalogIT {
         try (Connection conn = DriverManager.getConnection(getUrl());
                 Statement stmt = conn.createStatement()) {
             String viewIndexName1 = "I_" + generateUniqueName();
+            String schemaName = SchemaUtil.getSchemaNameFromFullName(viewName);
+            String viewIndexFullName1 = SchemaUtil.getTableName(schemaName, viewIndexName1);
             String viewIndexPhysicalName = MetaDataUtil.
                     getViewIndexPhysicalName(fullTableName);
             if (localIndex) {
@@ -959,11 +1177,13 @@ public class ViewIT extends SplitSystemCatalogIT {
                 assertEquals("PARALLEL "
                         + (saltBuckets == null ? 1 : saltBuckets) + "-WAY",
                     explainPlanAttributes.getIteratorTypeAndScanSize());
-                assertEquals(fullTableName,
+                assertEquals(viewIndexFullName1 + "(" + fullTableName + ")",
                     explainPlanAttributes.getTableName());
                 assertEquals(" [1,51]", explainPlanAttributes.getKeyRanges());
-                assertEquals("SERVER FILTER BY FIRST KEY ONLY",
-                    explainPlanAttributes.getServerWhereFilter());
+                assertTrue(explainPlanAttributes.getServerWhereFilter().
+                        equals("SERVER FILTER BY FIRST KEY ONLY") ||
+                        explainPlanAttributes.getServerWhereFilter().
+                                equals("SERVER FILTER BY EMPTY COLUMN ONLY"));
                 assertEquals("CLIENT MERGE SORT",
                     explainPlanAttributes.getClientSortAlgo());
             } else {
@@ -978,8 +1198,9 @@ public class ViewIT extends SplitSystemCatalogIT {
                 } else {
                     assertEquals("PARALLEL " + saltBuckets + "-WAY",
                         explainPlanAttributes.getIteratorTypeAndScanSize());
-                    assertEquals(" [0," + Short.MIN_VALUE + ",51] - ["
-                        + (saltBuckets - 1) + "," + Short.MIN_VALUE + ",51]",
+                    assertEquals(" [X'00'," + Short.MIN_VALUE + ",51] - ["
+                        + PVarbinary.INSTANCE.toStringLiteral(new byte[] {(byte)(saltBuckets - 1)})
+                        + "," + Short.MIN_VALUE + ",51]",
                         explainPlanAttributes.getKeyRanges());
                     assertEquals("CLIENT MERGE SORT",
                         explainPlanAttributes.getClientSortAlgo());
@@ -987,6 +1208,7 @@ public class ViewIT extends SplitSystemCatalogIT {
             }
 
             String viewIndexName2 = "I_" + generateUniqueName();
+            String viewIndexFullName2 = SchemaUtil.getTableName(schemaName, viewIndexName2);
             if (localIndex) {
                 stmt.execute("CREATE LOCAL INDEX " + viewIndexName2 + " on "
                         + viewName + "(s)");
@@ -1021,13 +1243,15 @@ public class ViewIT extends SplitSystemCatalogIT {
             explainPlanAttributes = plan.getPlanStepsAsAttributes();
             assertEquals("RANGE SCAN ",
                 explainPlanAttributes.getExplainScanType());
-            assertEquals("SERVER FILTER BY FIRST KEY ONLY",
-                explainPlanAttributes.getServerWhereFilter());
+            assertTrue(explainPlanAttributes.getServerWhereFilter().
+                    equals("SERVER FILTER BY FIRST KEY ONLY") ||
+                    explainPlanAttributes.getServerWhereFilter().
+                            equals("SERVER FILTER BY EMPTY COLUMN ONLY"));
             if (localIndex) {
                 physicalTableName = fullTableName;
                 assertEquals("PARALLEL " + (saltBuckets == null ? 1 : saltBuckets)
                     + "-WAY", explainPlanAttributes.getIteratorTypeAndScanSize());
-                assertEquals(fullTableName,
+                assertEquals(viewIndexFullName2 + "(" + fullTableName + ")",
                     explainPlanAttributes.getTableName());
                 assertEquals(" [" + (2) + ",'foo']",
                     explainPlanAttributes.getKeyRanges());
@@ -1044,8 +1268,9 @@ public class ViewIT extends SplitSystemCatalogIT {
                 } else {
                     assertEquals("PARALLEL " + saltBuckets + "-WAY",
                         explainPlanAttributes.getIteratorTypeAndScanSize());
-                    assertEquals(" [0," + (Short.MIN_VALUE + 1) + ",'foo'] - ["
-                        + (saltBuckets - 1) + "," + (Short.MIN_VALUE + 1)
+                    assertEquals(" [X'00'," + (Short.MIN_VALUE + 1) + ",'foo'] - ["
+                        + PVarbinary.INSTANCE.toStringLiteral(new byte[] {(byte)(saltBuckets - 1)})
+                        + "," + (Short.MIN_VALUE + 1)
                         + ",'foo']", explainPlanAttributes.getKeyRanges());
                     assertEquals("CLIENT MERGE SORT",
                         explainPlanAttributes.getClientSortAlgo());
