@@ -27,6 +27,7 @@ import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+import static org.junit.Assume.assumeFalse;
 
 import java.io.IOException;
 import java.math.BigDecimal;
@@ -37,6 +38,7 @@ import java.sql.PreparedStatement;
 import java.sql.ResultSet;
 import java.sql.SQLException;
 import java.sql.Statement;
+import java.util.Arrays;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Properties;
@@ -57,6 +59,8 @@ import org.apache.phoenix.compile.ColumnResolver;
 import org.apache.phoenix.compile.ExplainPlan;
 import org.apache.phoenix.compile.ExplainPlanAttributes;
 import org.apache.phoenix.compile.FromCompiler;
+import org.apache.phoenix.end2end.CreateTableIT;
+import org.apache.phoenix.end2end.IndexToolIT;
 import org.apache.phoenix.end2end.ParallelStatsDisabledIT;
 import org.apache.phoenix.exception.SQLExceptionCode;
 import org.apache.phoenix.jdbc.PhoenixConnection;
@@ -66,7 +70,9 @@ import org.apache.phoenix.jdbc.PhoenixStatement;
 import org.apache.phoenix.parse.NamedTableNode;
 import org.apache.phoenix.parse.TableName;
 import org.apache.phoenix.query.BaseTest;
+import org.apache.phoenix.query.QueryConstants;
 import org.apache.phoenix.query.QueryServices;
+import org.apache.phoenix.schema.PIndexState;
 import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTableImpl;
 import org.apache.phoenix.schema.PTableKey;
@@ -90,14 +96,18 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
     private static final Random RAND = new Random();
 
     private final boolean localIndex;
+    private final boolean uncovered;
     private final boolean transactional;
     private final TransactionFactory.Provider transactionProvider;
     private final boolean mutable;
+    private final boolean columnEncoded;
     private final String tableDDLOptions;
 
-    protected BaseIndexIT(boolean localIndex, boolean mutable, String transactionProvider, boolean columnEncoded) {
+    protected BaseIndexIT(boolean localIndex, boolean uncovered, boolean mutable, String transactionProvider, boolean columnEncoded) {
         this.localIndex = localIndex;
+        this.uncovered = uncovered;
         this.mutable = mutable;
+        this.columnEncoded = columnEncoded;
         StringBuilder optionBuilder = new StringBuilder();
         if (!columnEncoded) {
             if (optionBuilder.length()!=0)
@@ -138,9 +148,10 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             Statement stmt = conn.createStatement();
             stmt.execute(ddl);
             BaseTest.populateTestTable(fullTableName);
-            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + " INDEX " + indexName + " ON " + fullTableName
+            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName
                     + " (char_col1 ASC, int_col1 ASC)"
-                    + " INCLUDE (long_col1, long_col2)";
+                    + (uncovered ? "" : " INCLUDE (long_col1, long_col2)");
             stmt.execute(ddl);
 
             String query = "SELECT d.char_col1, int_col1 from " + fullTableName + " as d";
@@ -152,17 +163,22 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
                 plan.getPlanStepsAsAttributes();
             assertEquals("PARALLEL 1-WAY",
                 explainPlanAttributes.getIteratorTypeAndScanSize());
-            assertEquals("SERVER FILTER BY FIRST KEY ONLY",
-                explainPlanAttributes.getServerWhereFilter());
+            if (!uncovered) {
+                // Optimizer would not select the uncovered index for this query
+                assertEquals(columnEncoded ? "SERVER FILTER BY FIRST KEY ONLY" :
+                                "SERVER FILTER BY EMPTY COLUMN ONLY",
+                        explainPlanAttributes.getServerWhereFilter());
+            }
 
             if (localIndex) {
-                assertEquals(fullTableName, explainPlanAttributes.getTableName());
+                assertEquals(fullIndexName + "(" + fullTableName + ")",
+                        explainPlanAttributes.getTableName());
                 assertEquals(" [1]", explainPlanAttributes.getKeyRanges());
                 assertEquals("CLIENT MERGE SORT",
                     explainPlanAttributes.getClientSortAlgo());
                 assertEquals("RANGE SCAN ",
                     explainPlanAttributes.getExplainScanType());
-            } else {
+            } else if (!uncovered) {
                 assertEquals(fullIndexName, explainPlanAttributes.getTableName());
                 assertNull(explainPlanAttributes.getClientSortAlgo());
                 assertEquals("FULL SCAN ",
@@ -211,9 +227,10 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             Statement stmt = conn.createStatement();
             stmt.execute(ddl);
             BaseTest.populateTestTable(fullTableName);
-            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + " INDEX " + indexName + " ON " + fullTableName
+            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName
                         + " (long_pk, varchar_pk)"
-                        + " INCLUDE (long_col1, long_col2)";
+                        + (uncovered ? "" : " INCLUDE (long_col1, long_col2)");
             stmt.execute(ddl);
 
             ResultSet rs;
@@ -262,7 +279,7 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
         Iterator<Pair<byte[],List<Cell>>> iterator = PhoenixRuntime.getUncommittedDataIterator(conn);
         if (iterator.hasNext()) {
             byte[] tableName = iterator.next().getFirst(); // skip data table mutations
-            PTable table = PhoenixRuntime.getTable(conn, Bytes.toString(tableName));
+            PTable table = conn.unwrap(PhoenixConnection.class).getTable(Bytes.toString(tableName));
             boolean clientSideUpdate = (!localIndex || (transactional && table.getTransactionProvider().getTransactionProvider().isUnsupported(Feature.MAINTAIN_LOCAL_INDEX_ON_SERVER))) 
                     && (!mutable || transactional);
             if (!clientSideUpdate) {
@@ -330,9 +347,10 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
                 }
 
                 String indexName = SchemaUtil.getTableNameFromFullName(fullIndexName);
-                ddl = "CREATE " + (localIndex ? "LOCAL" : "") + " INDEX " + indexName + " ON " + fullTableName
+                ddl = "CREATE " + (localIndex ? "LOCAL" : "") + (uncovered ? "UNCOVERED" : "")
+                        + " INDEX " + indexName + " ON " + fullTableName
                         + " (long_pk, varchar_pk)"
-                        + " INCLUDE (long_col1, long_col2)";
+                        + (uncovered ? "" : " INCLUDE (long_col1, long_col2)");
                 stmt1.execute(ddl);
 
                 /*
@@ -388,9 +406,10 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             Statement stmt = conn.createStatement();
             stmt.execute(ddl);
             BaseTest.populateTestTable(fullTableName);
-            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + " INDEX " + indexName + " ON " + fullTableName
+            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName
                         + " (long_col1, long_col2)"
-                        + " INCLUDE (decimal_col1, decimal_col2)";
+                        + (uncovered ? "" : " INCLUDE (decimal_col1, decimal_col2)");
             stmt.execute(ddl);
         }
         try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
@@ -442,7 +461,8 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             Statement stmt = conn.createStatement();
             stmt.execute(ddl);
             BaseTest.populateTestTable(fullTableName);
-            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + " INDEX " + indexName + " ON " + fullTableName + " (int_col2)";
+            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName + " (int_col2)";
             stmt.execute(ddl);
             ResultSet rs;
             rs = conn.createStatement().executeQuery("SELECT int_col2, COUNT(*) FROM " + fullTableName + " GROUP BY int_col2");
@@ -463,7 +483,8 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             Statement stmt = conn.createStatement();
             stmt.execute(ddl);
             BaseTest.populateTestTable(fullTableName);
-            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + " INDEX " + indexName + " ON " + fullTableName + " (int_col2)";
+            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName + " (int_col2)";
             conn.createStatement().execute(ddl);
             ResultSet rs = conn.createStatement().executeQuery("SELECT distinct int_col2 FROM " + fullTableName + " where int_col2 > 0");
             assertTrue(rs.next());
@@ -488,7 +509,8 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             Statement stmt = conn.createStatement();
             stmt.execute(ddl);
             BaseTest.populateTestTable(fullTableName);
-            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + " INDEX " + indexName + " ON " + fullTableName + " (int_col1)";
+            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName + " (int_col1)";
             stmt.execute(ddl);
             ResultSet rs = conn.createStatement().executeQuery("SELECT int_col1 FROM " + fullTableName + " where int_col1 IN (1, 2, 3, 4)");
             assertTrue(rs.next());
@@ -523,7 +545,9 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
 
             String options = localIndex ? "SALT_BUCKETS=10, MULTI_TENANT=true, IMMUTABLE_ROWS=true, DISABLE_WAL=true" : "";
             conn.createStatement().execute(
-                    "CREATE INDEX " + indexName + " ON " + fullTableName + " (v1) INCLUDE (v2) " + options);
+                    "CREATE " + (uncovered ? "UNCOVERED" : "") + " INDEX " + indexName
+                            + " ON " + fullTableName + " (v1)"
+                            + (uncovered ? " " : "INCLUDE (v2) ") + options);
             query = "SELECT * FROM " + fullIndexName;
             rs = conn.createStatement().executeQuery(query);
             assertFalse(rs.next());
@@ -557,10 +581,13 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
 
             TestUtil.createMultiCFTestTable(conn, fullTableName, tableDDLOptions);
             populateMultiCFTestTable(fullTableName, date);
-            String ddl = "CREATE " + (localIndex ? " LOCAL " : "") + " INDEX " + indexName + " ON " + fullTableName + " (date_col)";
+            String ddl = "CREATE " + (localIndex ? " LOCAL " : "")
+                    + (uncovered ? "UNCOVERED" : "") + " INDEX " + indexName
+                    + " ON " + fullTableName + " (date_col)";
             conn.createStatement().execute(ddl);
 
-            String query = "SELECT int_pk from " + fullTableName ;
+            String query = "SELECT" + (uncovered ? " /*+ INDEX(" + fullTableName + " "
+                    + indexName + ")*/ " : " ") + "int_pk from " + fullTableName;
             ExplainPlan plan = conn.prepareStatement(query)
                 .unwrap(PhoenixPreparedStatement.class).optimizeQuery()
                 .getExplainPlan();
@@ -568,12 +595,13 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
                 plan.getPlanStepsAsAttributes();
             assertEquals("PARALLEL 1-WAY",
                 explainPlanAttributes.getIteratorTypeAndScanSize());
-            assertEquals("SERVER FILTER BY FIRST KEY ONLY",
-                explainPlanAttributes.getServerWhereFilter());
+            assertEquals(columnEncoded ? "SERVER FILTER BY FIRST KEY ONLY" :
+                            "SERVER FILTER BY EMPTY COLUMN ONLY",
+                    explainPlanAttributes.getServerWhereFilter());
             if (localIndex) {
                 assertEquals("RANGE SCAN ",
                     explainPlanAttributes.getExplainScanType());
-                assertEquals(fullTableName,
+                assertEquals(fullIndexName + "(" + fullTableName + ")",
                     explainPlanAttributes.getTableName());
                 assertEquals("CLIENT MERGE SORT",
                     explainPlanAttributes.getClientSortAlgo());
@@ -602,12 +630,14 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             explainPlanAttributes = plan.getPlanStepsAsAttributes();
             assertEquals("PARALLEL 1-WAY",
                 explainPlanAttributes.getIteratorTypeAndScanSize());
-            assertEquals("SERVER FILTER BY FIRST KEY ONLY",
-                explainPlanAttributes.getServerWhereFilter());
+            assertEquals(columnEncoded ? "SERVER FILTER BY FIRST KEY ONLY" :
+                            "SERVER FILTER BY EMPTY COLUMN ONLY",
+                    explainPlanAttributes.getServerWhereFilter());
             if (localIndex) {
                 assertEquals("RANGE SCAN ",
                     explainPlanAttributes.getExplainScanType());
-                assertEquals(fullTableName, explainPlanAttributes.getTableName());
+                assertEquals(fullIndexName + "(" + fullTableName + ")",
+                        explainPlanAttributes.getTableName());
                 assertEquals("CLIENT MERGE SORT",
                     explainPlanAttributes.getClientSortAlgo());
                 assertEquals(" [1]", explainPlanAttributes.getKeyRanges());
@@ -646,9 +676,12 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             rs = conn.createStatement().executeQuery(query);
             assertFalse(rs.next());
 
-            ddl = "CREATE " + (localIndex ? " LOCAL " : "") + " INDEX " + indexName + " ON " + fullTableName + " (v2 DESC) INCLUDE (v1)";
+            ddl = "CREATE " + (localIndex ? " LOCAL " : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName + " (v2 DESC)"
+                    + (uncovered ? "" : "INCLUDE (v1)");
             conn.createStatement().execute(ddl);
-            query = "SELECT * FROM " + fullIndexName;
+            query = "SELECT" + (uncovered ? " /*+ INDEX(" + fullTableName + " "
+                    + indexName + ")*/ * FROM " + fullTableName : " * FROM " + fullIndexName);
             rs = conn.createStatement().executeQuery(query);
             assertFalse(rs.next());
 
@@ -663,7 +696,8 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             stmt.execute();
             conn.commit();
 
-            query = "SELECT * FROM " + fullTableName;
+            query = "SELECT" + (uncovered ? " /*+ INDEX(" + fullTableName + " "
+                    + indexName + ")*/" : "") + " * FROM " + fullTableName;
             ExplainPlan plan = conn.prepareStatement(query)
                 .unwrap(PhoenixPreparedStatement.class).optimizeQuery()
                 .getExplainPlan();
@@ -674,7 +708,7 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             if (localIndex) {
                 assertEquals("RANGE SCAN ",
                     explainPlanAttributes.getExplainScanType());
-                assertEquals(fullTableName,
+                assertEquals(fullIndexName + "(" + fullTableName + ")",
                     explainPlanAttributes.getTableName());
                 assertEquals("CLIENT MERGE SORT",
                     explainPlanAttributes.getClientSortAlgo());
@@ -718,7 +752,7 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             assertEquals("CLIENT MERGE SORT",
                 explainPlanAttributes.getClientSortAlgo());
             if (localIndex) {
-                assertEquals(fullTableName,
+                assertEquals(fullIndexName + "(" + fullTableName + ")",
                     explainPlanAttributes.getTableName());
             } else {
                 assertEquals(fullIndexName,
@@ -749,7 +783,9 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             query = "SELECT * FROM " + fullTableName;
             rs = conn.createStatement().executeQuery(query);
             assertFalse(rs.next());
-            ddl = "CREATE " + (localIndex ? " LOCAL " : "") + " INDEX " + indexName + " ON " + fullTableName + " (v2 DESC) INCLUDE (a.v1)";
+            ddl = "CREATE " + (localIndex ? " LOCAL " : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName + " (v2 DESC)"
+                    + (uncovered ? "" : "INCLUDE (a.v1)");
             conn.createStatement().execute(ddl);
             query = "SELECT * FROM " + fullIndexName;
             rs = conn.createStatement().executeQuery(query);
@@ -780,7 +816,8 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
                 explainPlanAttributes.getExplainScanType());
             assertEquals(fullTableName, explainPlanAttributes.getTableName());
 
-            query = "SELECT a.* FROM " + fullTableName;
+            query = "SELECT" + (uncovered ? " /*+ INDEX(" + fullTableName + " "
+                    + indexName + ")*/ " : " ") + "a.* FROM " + fullTableName;
             plan = conn.prepareStatement(query)
                 .unwrap(PhoenixPreparedStatement.class).optimizeQuery()
                 .getExplainPlan();
@@ -791,7 +828,7 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             if(localIndex) {
                 assertEquals("RANGE SCAN ",
                     explainPlanAttributes.getExplainScanType());
-                assertEquals(fullTableName,
+                assertEquals(fullIndexName + "(" + fullTableName + ")",
                     explainPlanAttributes.getTableName());
                 assertEquals(" [1]", explainPlanAttributes.getKeyRanges());
                 assertEquals("CLIENT MERGE SORT",
@@ -837,7 +874,8 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             assertFalse(rs.next());
 
             conn.createStatement().execute(
-                    "CREATE " + (localIndex ? "LOCAL " : "") + "INDEX " + indexName + " ON " + fullTableName + " (v1, v2)");
+                    "CREATE " + (localIndex ? "LOCAL " : "") + (uncovered ? "UNCOVERED" : "")
+                            + " INDEX " + indexName + " ON " + fullTableName + " (v1, v2)");
             query = "SELECT * FROM " + fullIndexName;
             rs = conn.createStatement().executeQuery(query);
             assertFalse(rs.next());
@@ -923,7 +961,8 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             assertFalse(rs.next());
 
             conn.createStatement().execute(
-                    "CREATE " + (localIndex ? "LOCAL " : "") + "INDEX " + indexName + " ON " + testTable + " (v1, v2)");
+                    "CREATE " + (localIndex ? "LOCAL " : "") + (uncovered ? "UNCOVERED" : "")
+                            + " INDEX " + indexName + " ON " + testTable + " (v1, v2)");
             query = "SELECT * FROM " + fullIndexName;
             rs = conn.createStatement().executeQuery(query);
             assertFalse(rs.next());
@@ -962,20 +1001,23 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             assertFalse(rs.next());
             
             // make sure the index is working as expected
-            query = "SELECT * FROM " + testTable;
+            query = "SELECT" + (uncovered ? " /*+ INDEX(" + testTable + " "
+                    + indexName + ")*/ " : " ") + "* FROM "+ testTable;
             ExplainPlan plan = conn.prepareStatement(query)
                 .unwrap(PhoenixPreparedStatement.class).optimizeQuery()
                 .getExplainPlan();
             ExplainPlanAttributes explainPlanAttributes =
                 plan.getPlanStepsAsAttributes();
-            assertEquals("SERVER FILTER BY FIRST KEY ONLY",
-                explainPlanAttributes.getServerWhereFilter());
+            assertEquals(columnEncoded ? "SERVER FILTER BY FIRST KEY ONLY" :
+                            "SERVER FILTER BY EMPTY COLUMN ONLY",
+                    explainPlanAttributes.getServerWhereFilter());
             if (localIndex) {
                 assertEquals("PARALLEL 2-WAY",
                     explainPlanAttributes.getIteratorTypeAndScanSize());
                 assertEquals("RANGE SCAN ",
                     explainPlanAttributes.getExplainScanType());
-                assertEquals(testTable, explainPlanAttributes.getTableName());
+                assertEquals(fullIndexName + "(" + testTable + ")",
+                        explainPlanAttributes.getTableName());
                 assertEquals(" [1]", explainPlanAttributes.getKeyRanges());
                 assertEquals("CLIENT MERGE SORT",
                     explainPlanAttributes.getClientSortAlgo());
@@ -1024,7 +1066,9 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             long ts = conn.unwrap(PhoenixConnection.class).getTable(new PTableKey(null,fullTableName)).getTimeStamp();
             assertFalse(rs.next());
             conn.createStatement().execute(
-                    "CREATE " + (localIndex ? "LOCAL " : "") + "INDEX " + indexName + " ON " + fullTableName + "(\"v2\") INCLUDE (\"V1\")");
+                    "CREATE " + (localIndex ? "LOCAL " : "") + (uncovered ? "UNCOVERED " : " ")
+                            + "INDEX " + indexName + " ON " + fullTableName + "(\"v2\")"
+                    + (uncovered ? "" : " INCLUDE (\"V1\")"));
             query = "SELECT * FROM "+fullIndexName;
             rs = conn.createStatement().executeQuery(query);
             assertFalse(rs.next());
@@ -1053,7 +1097,7 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             assertEquals("RANGE SCAN ",
                 explainPlanAttributes.getExplainScanType());
             if (localIndex) {
-                assertEquals(fullTableName,
+                assertEquals(fullIndexName + "(" + fullTableName + ")",
                     explainPlanAttributes.getTableName());
                 assertEquals(" [1,'1']", explainPlanAttributes.getKeyRanges());
             } else {
@@ -1094,7 +1138,7 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             if (localIndex) {
                 assertEquals("RANGE SCAN ",
                     explainPlanAttributes.getExplainScanType());
-                assertEquals(fullTableName,
+                assertEquals(fullIndexName + "(" + fullTableName + ")",
                     explainPlanAttributes.getTableName());
                 assertEquals(" [1]", explainPlanAttributes.getKeyRanges());
                 assertEquals("CLIENT MERGE SORT",
@@ -1173,7 +1217,8 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             ResultSet rs;
             String ddl = "CREATE TABLE " + fullTableName +"  (PK1 CHAR(2) NOT NULL PRIMARY KEY, CF1.COL1 BIGINT) " + tableDDLOptions;
             conn.createStatement().execute(ddl);
-            ddl = "CREATE " + (localIndex ? "LOCAL " : "") + "INDEX " + indexName + " ON " + fullTableName + "(COL1)";
+            ddl = "CREATE " + (localIndex ? "LOCAL " : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName + "(COL1)";
             conn.createStatement().execute(ddl);
 
             query = "SELECT COUNT(COL1) FROM " + fullTableName +" WHERE COL1 IN (1,25,50,75,100)";
@@ -1208,14 +1253,18 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             TestUtil.createMultiCFTestTable(conn, fullTableName, tableDDLOptions);
             populateMultiCFTestTable(fullTableName, date);
             String ddl = null;
-            ddl = "CREATE " + (localIndex ? "LOCAL " : "") + "INDEX " + indexName + " ON " + fullTableName + " (decimal_pk) INCLUDE (decimal_col1, decimal_col2)";
+            ddl = "CREATE " + (localIndex ? "LOCAL " : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName + " (decimal_pk)"
+                    + (uncovered ? "" : "INCLUDE (decimal_col1, decimal_col2)");
             conn.createStatement().execute(ddl);
             
             if (transactional && transactionProvider == TransactionFactory.Provider.OMID) {
                 assertShadowCellsExist(conn, fullTableName, fullIndexName);
             }
 
-            query = "SELECT decimal_pk, decimal_col1, decimal_col2 from " + fullTableName ;
+            query = "SELECT" + (uncovered ? " /*+ INDEX(" + fullTableName + " " + indexName
+                    + ")*/ " : " ") + "decimal_pk, decimal_col1, decimal_col2 from "
+                    + fullTableName ;
             ExplainPlan plan = conn.prepareStatement(query)
                 .unwrap(PhoenixPreparedStatement.class).optimizeQuery()
                 .getExplainPlan();
@@ -1226,7 +1275,7 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             if (localIndex) {
                 assertEquals("RANGE SCAN ",
                     explainPlanAttributes.getExplainScanType());
-                assertEquals(fullTableName,
+                assertEquals(fullIndexName + "(" + fullTableName + ")",
                     explainPlanAttributes.getTableName());
                 assertEquals(" [1]", explainPlanAttributes.getKeyRanges());
                 assertEquals("CLIENT MERGE SORT",
@@ -1321,7 +1370,8 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
                 ddl += "(p1 desc, p2))";
             }
             stmt.executeUpdate(ddl);
-            ddl = "CREATE "+ (localIndex ? "LOCAL " : "") + " INDEX " + indexName + " on " + fullTableName + "(a)";
+            ddl = "CREATE "+ (localIndex ? "LOCAL " : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " on " + fullTableName + "(a)";
             stmt.executeUpdate(ddl);
 
             // upsert a single row
@@ -1351,7 +1401,9 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
             String tableName =
                     initATableValues(generateUniqueName(), tenantId, getDefaultSplits(tenantId),
                         new Date(System.currentTimeMillis()), null, getUrl(), tableDDLOptions);
-            String ddl = "CREATE "+ (localIndex ? "LOCAL " : "") + " INDEX " + indexName + " on " + tableName + "(A_STRING) INCLUDE (B_STRING)";
+            String ddl = "CREATE "+ (localIndex ? "LOCAL " : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " on " + tableName + "(A_STRING)"
+            + (uncovered ? "" : " INCLUDE (B_STRING)");
             conn.createStatement().executeUpdate(ddl);
             String query = "SELECT ENTITY_ID,A_STRING,B_STRING FROM " + tableName + " WHERE organization_id=? and entity_id=?";
 
@@ -1393,4 +1445,192 @@ public abstract class BaseIndexIT extends ParallelStatsDisabledIT {
         }
     }
 
+    /**
+     * Tests that we add LAST_DDL_TIMESTAMP when we create an index and we update LAST_DDL_TIMESTAMP when we update
+     * an index.
+     * @throws Exception
+     */
+    @Test
+    public void testLastDDLTimestampOnIndexes() throws Exception {
+        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
+        String tableName = "TBL_" + generateUniqueName();
+        String indexName = "IND_" + generateUniqueName();
+        String fullTableName = SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, tableName);
+        String fullIndexName = SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, indexName);
+
+        String ddl ="CREATE TABLE " + fullTableName + TestUtil.TEST_TABLE_SCHEMA + tableDDLOptions;
+        long startTs = EnvironmentEdgeManager.currentTimeMillis();
+        try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
+            conn.setAutoCommit(true);
+            Statement stmt = conn.createStatement();
+            stmt.execute(ddl);
+            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName
+                    + " (long_col1, long_col2)"
+                    + (uncovered ? "" : " INCLUDE (decimal_col1, decimal_col2)");
+            stmt.execute(ddl);
+            TestUtil.waitForIndexState(conn, fullIndexName, PIndexState.ACTIVE);
+
+            long activeIndexLastDDLTimestamp = CreateTableIT.verifyLastDDLTimestamp(fullIndexName, startTs, conn);
+            Thread.sleep(1);
+            // Disable an index. This should change the LAST_DDL_TIMESTAMP.
+            String disableIndexDDL = "ALTER INDEX " + indexName + " ON " +  TestUtil.DEFAULT_SCHEMA_NAME +
+                    QueryConstants.NAME_SEPARATOR + tableName + " DISABLE";
+            stmt.execute(disableIndexDDL);
+            TestUtil.waitForIndexState(conn, fullIndexName, PIndexState.DISABLE);
+            CreateTableIT.verifyLastDDLTimestamp(fullIndexName, activeIndexLastDDLTimestamp  + 1, conn);
+        }
+    }
+
+    /**
+     * Tests that we add LAST_DDL_TIMESTAMP when we create an async index
+     * and we update LAST_DDL_TIMESTAMP when we update an index.
+     * For ASYNC indexes, the state goes from BUILDING --> ACTIVE --> DISABLE
+     * Verify that LAST_DDL_TIMESTAMP changes at every step.
+     * @throws Exception
+     */
+    @Test
+    public void testLastDDLTimestampOnAsyncIndexes() throws Exception {
+        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
+        String tableName = "TBL_" + generateUniqueName();
+        String indexName = "IND_" + generateUniqueName();
+        String fullTableName = SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, tableName);
+        String fullIndexName = SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, indexName);
+
+        String ddl ="CREATE TABLE " + fullTableName + TestUtil.TEST_TABLE_SCHEMA + tableDDLOptions;
+        long startTs = EnvironmentEdgeManager.currentTimeMillis();
+        try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
+            conn.setAutoCommit(true);
+            Statement stmt = conn.createStatement();
+            stmt.execute(ddl);
+            ddl = "CREATE " + (localIndex ? "LOCAL" : "") + (uncovered ? "UNCOVERED" : "")
+                    + " INDEX " + indexName + " ON " + fullTableName
+                    + " (long_col1, long_col2)"
+                    + (uncovered ? " ASYNC" : " INCLUDE (decimal_col1, decimal_col2) ASYNC");
+            stmt.execute(ddl);
+            TestUtil.waitForIndexState(conn, fullIndexName, PIndexState.BUILDING);
+            long buildingIndexLastDDLTimestamp = CreateTableIT.verifyLastDDLTimestamp(fullIndexName, startTs, conn);
+            Thread.sleep(1);
+
+            // run the index MR job.
+            IndexToolIT.runIndexTool(false, TestUtil.DEFAULT_SCHEMA_NAME, tableName, indexName);
+            TestUtil.waitForIndexState(conn, fullIndexName, PIndexState.ACTIVE);
+            long activeIndexLastDDLTimestamp = CreateTableIT.verifyLastDDLTimestamp(
+                    fullIndexName, buildingIndexLastDDLTimestamp + 1, conn);
+            Thread.sleep(1);
+
+            // Disable an index. This should change the LAST_DDL_TIMESTAMP.
+            String disableIndexDDL = "ALTER INDEX " + indexName + " ON " +  TestUtil.DEFAULT_SCHEMA_NAME +
+                    QueryConstants.NAME_SEPARATOR + tableName + " DISABLE";
+            stmt.execute(disableIndexDDL);
+            TestUtil.waitForIndexState(conn, fullIndexName, PIndexState.DISABLE);
+            CreateTableIT.verifyLastDDLTimestamp(fullIndexName, activeIndexLastDDLTimestamp + 1, conn);
+        }
+    }
+
+    @Test
+    public void testSelectUncoveredWithCoveredFieldSimple() throws Exception {
+        assumeFalse(localIndex);
+        assumeFalse(uncovered);
+        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
+        String tableName = "TBL_" + generateUniqueName();
+        String indexName = "IND_" + generateUniqueName();
+        String fullTableName = SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, tableName);
+        try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
+            conn.setAutoCommit(false);
+            String ddl =
+                    "CREATE TABLE " + fullTableName
+                            + " (v1 integer, k integer primary key, v2 integer, v3 integer, v4 integer) "
+                            + tableDDLOptions;
+            String upsert = "UPSERT INTO " + fullTableName + " values (1, 2, 3, 4, 5)";
+            Statement stmt = conn.createStatement();
+            stmt.execute(ddl);
+            stmt.execute(upsert);
+            conn.commit();
+            ddl =
+                    "CREATE " + (uncovered ? "UNCOVERED" : "") + " INDEX " + indexName + " ON "
+                            + fullTableName + " (v2) include(v3)";
+            conn.createStatement().execute(ddl);
+            ResultSet rs =
+                    conn.createStatement().executeQuery("SELECT /*+ INDEX(" + fullTableName + " "
+                            + indexName + ")*/ * FROM " + fullTableName + " where v2=3 and v3=4");
+            // We're only testing the projector
+            assertTrue(rs.next());
+            assertEquals("1", rs.getString("v1"));
+            assertEquals("2", rs.getString("k"));
+            assertEquals("3", rs.getString("v2"));
+            assertEquals("4", rs.getString("v3"));
+            assertEquals("5", rs.getString("v4"));
+            assertFalse(rs.next());
+        }
+    }
+
+    @Test
+    public void testSelectUncoveredWithCoveredField() throws Exception {
+        assumeFalse(localIndex);
+        assumeFalse(uncovered);
+        Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
+        String tableName = "TBL_" + generateUniqueName();
+        String indexName = "IND_" + generateUniqueName();
+        String fullTableName = SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, tableName);
+        String fullIndexName = SchemaUtil.getTableName(TestUtil.DEFAULT_SCHEMA_NAME, indexName);
+
+
+        try (Connection conn = DriverManager.getConnection(getUrl(), props);
+                Statement stmt = conn.createStatement()) {
+            conn.setAutoCommit(false);
+            String ddl =
+                    "CREATE TABLE " + fullTableName + TestUtil.TEST_TABLE_SCHEMA + tableDDLOptions;
+            stmt.execute(ddl);
+            BaseTest.populateTestTable(fullTableName);
+            conn.commit();
+            ddl =
+                    "CREATE " + (uncovered ? "UNCOVERED" : "") + " INDEX " + indexName + " ON "
+                            + fullTableName + " ( int_col1 ASC)"
+                            + " INCLUDE (long_col1, long_col2)"
+            ;
+            stmt.execute(ddl);
+
+            String query;
+            ResultSet rs;
+
+            for (String columns : Arrays.asList(new String[] { "*",
+                    "varchar_pk,char_pk,int_pk,long_pk,decimal_pk,date_pk,a.varchar_col1,a.char_col1,a.int_col1,a.long_col1,a.decimal_col1,a.date1,b.varchar_col2,b.char_col2,b.int_col2,b.long_col2,b.decimal_col2,b.date2",
+                    "varchar_pk,char_pk,int_pk,long_pk,decimal_pk,date_pk,varchar_col1,char_col1,int_col1,long_col1,decimal_col1,date1,varchar_col2,char_col2,int_col2,long_col2,decimal_col2,date2", })) {
+
+                query =
+                        "SELECT /*+ INDEX(" + fullTableName + " " + indexName + ")*/ " + columns
+                                + " from " + fullTableName + " where int_col1=2 and long_col1=2";
+                rs = stmt.executeQuery("Explain " + query);
+                String explainPlan = QueryUtil.getExplainPlan(rs);
+                assertEquals("bad plan with columns:" + columns,
+                    "CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullIndexName + " [2]\n"
+                            + "    SERVER MERGE [A.VARCHAR_COL1, A.CHAR_COL1, A.DECIMAL_COL1, A.DATE1, B.VARCHAR_COL2, B.CHAR_COL2, B.INT_COL2, B.DECIMAL_COL2, B.DATE2]\n"
+                            + "    SERVER FILTER BY A.\"LONG_COL1\" = 2",
+                    explainPlan);
+                rs = stmt.executeQuery(query);
+                assertTrue(rs.next());
+                // Test the projector thoroughly
+                assertEquals("varchar1", rs.getString("varchar_pk"));
+                assertEquals("char1", rs.getString("char_pk"));
+                assertEquals("1", rs.getString("int_pk"));
+                assertEquals("1", rs.getString("long_pk"));
+                assertEquals("1", rs.getString("decimal_pk"));
+                assertEquals("2015-01-01 00:00:00.000", rs.getString("date_pk"));
+                assertEquals("varchar_a", rs.getString("varchar_col1"));
+                assertEquals("chara", rs.getString("char_col1"));
+                assertEquals("2", rs.getString("int_col1"));
+                assertEquals("2", rs.getString("long_col1"));
+                assertEquals("2", rs.getString("decimal_col1"));
+                assertEquals("2015-01-01 00:00:00.000", rs.getString("date1"));
+                assertEquals("varchar_b", rs.getString("varchar_col2"));
+                assertEquals("charb", rs.getString("char_col2"));
+                assertEquals("3", rs.getString("int_col2"));
+                assertEquals("3", rs.getString("long_col2"));
+                assertEquals("3", rs.getString("decimal_col2"));
+                assertEquals("2015-01-01 00:00:00.000", rs.getString("date2"));
+                assertFalse(rs.next());
+            }
+        }
+    }
 }
