@@ -86,7 +86,8 @@ import org.junit.experimental.categories.Category;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
 import org.junit.runners.Parameterized.Parameters;
-
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 /**
@@ -100,6 +101,9 @@ import org.apache.phoenix.thirdparty.com.google.common.collect.Maps;
 @Category(NeedsOwnMiniClusterTest.class)
 @RunWith(Parameterized.class)
 public class MutableIndexFailureIT extends BaseTest {
+
+    private static final Logger LOGGER = LoggerFactory.getLogger(MutableIndexFailureIT.class);
+
     public static volatile boolean FAIL_WRITE = false;
     public static volatile String fullTableName;
     
@@ -175,27 +179,25 @@ public class MutableIndexFailureIT extends BaseTest {
         return serverProps;
     }
 
-    @Parameters(name = "MutableIndexFailureIT_transactionProvider={0},localIndex={1},isNamespaceMapped={2},disableIndexOnWriteFailure={3},failRebuildTask={4},throwIndexWriteFailure={5}") // name is used by failsafe as file name in reports
+    // name is used by failsafe as file name in reports
+    @Parameters(name = "MutableIndexFailureIT_transactionProvider={0},localIndex={1},isNamespaceMapped={2},disableIndexOnWriteFailure={3},failRebuildTask={4},throwIndexWriteFailure={5}")
     public static synchronized Collection<Object[]> data() {
-        return TestUtil.filterTxParamData(
-                Arrays.asList(new Object[][] { 
-                    // note - can't disableIndexOnWriteFailure without throwIndexWriteFailure, PHOENIX-4130
-                    { null, false, false, false, false, false},
-                    { null, false, false, true, false, null},
-                    { "TEPHRA", false, false, true, false, null},
-                    { "OMID", false, false, true, false, null},
-                    { null, true, false, null, false, null},
-                    { "TEPHRA", true, false, true, false, null},
-                    { null, false, false, false, false, null},
-                    { null, true, false, false, false, null},
-                    { null, false, false, false, false, null},
-                    { null, false, false, true, false, null},
-                    { null, true, false, true, false, null},
-                    { null, true, false, true, false, null},
-                    { null, false, false, true, true, null},
-                    { null, false, false, false, true, false},
-                    }), 0);
-        
+        return Arrays.asList(new Object[][] {
+            // Note: Can't disableIndexOnWriteFailure without throwIndexWriteFailure, PHOENIX-4130
+            { null, false, false, false, false, false},
+            { null, false, false, true, false, null},
+            // Note: OMID does not support local indexes
+            { "OMID", false, false, true, false, null},
+            { null, true, false, null, false, null},
+            { null, false, false, false, false, null},
+            { null, true, false, false, false, null},
+            { null, false, false, false, false, null},
+            { null, false, false, true, false, null},
+            { null, true, false, true, false, null},
+            { null, true, false, true, false, null},
+            { null, false, false, true, true, null},
+            { null, false, false, false, true, false},
+        });
     }
 
     private void runRebuildTask(Connection conn) throws InterruptedException, SQLException {
@@ -227,7 +229,7 @@ public class MutableIndexFailureIT extends BaseTest {
                         + " Disable timestamp: " + idx.getIndexDisableTimestamp());
         }
         System.out.println("************Index state from server  " + s + "******************");
-        table = PhoenixRuntime.getTableNoCache(phxConn, fullTableName);
+        table = phxConn.getTableNoCache(fullTableName);
         for (PTable idx : table.getIndexes()) {
             System.out.println(
                 "Index Name: " + idx.getName().getString() + " State: " + idx.getIndexState()
@@ -475,6 +477,7 @@ public class MutableIndexFailureIT extends BaseTest {
                         }
                         conn.commit();
                     } catch (SQLException e) {
+                        LOGGER.warn("Error while adding row", e);
                         return false;
                     }
                     return true;
@@ -504,8 +507,9 @@ public class MutableIndexFailureIT extends BaseTest {
         ResultSet rs = conn.createStatement().executeQuery(query);
         String expectedPlan = " OVER "
                 + (localIndex
-                        ? Bytes.toString(
-                                SchemaUtil.getPhysicalTableName(fullTableName.getBytes(), isNamespaceMapped).getName())
+                        ? fullIndexName + "(" + Bytes.toString(
+                                SchemaUtil.getPhysicalTableName(fullTableName.getBytes(),
+                                        isNamespaceMapped).getName()) + ")"
                         : SchemaUtil.getPhysicalTableName(fullIndexName.getBytes(), isNamespaceMapped).getNameAsString());
         String explainPlan = QueryUtil.getExplainPlan(conn.createStatement().executeQuery("EXPLAIN " + query));
         assertTrue(explainPlan, explainPlan.contains(expectedPlan));
