@@ -34,11 +34,16 @@ import java.util.Collection;
 import java.util.Properties;
 
 import org.apache.hadoop.hbase.TableName;
+import org.apache.hadoop.hbase.client.HBaseAdmin;
+import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.hbase.util.Threads;
+import org.apache.phoenix.end2end.CreateTableIT;
 import org.apache.phoenix.end2end.ParallelStatsDisabledIT;
 import org.apache.phoenix.end2end.ParallelStatsDisabledTest;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
 import org.apache.phoenix.query.QueryServices;
+import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTableKey;
 import org.apache.phoenix.util.IndexScrutiny;
 import org.apache.phoenix.util.PhoenixRuntime;
@@ -62,9 +67,11 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
     private static final Logger LOGGER = LoggerFactory.getLogger(MutableIndexIT.class);
     protected final boolean localIndex;
     private final String tableDDLOptions;
+    private final boolean columnEncoded;
     
     public MutableIndexIT(Boolean localIndex, String txProvider, Boolean columnEncoded) {
         this.localIndex = localIndex;
+        this.columnEncoded = columnEncoded;
         StringBuilder optionBuilder = new StringBuilder();
         if (txProvider != null) {
             optionBuilder.append("TRANSACTIONAL=true," + PhoenixDatabaseMetaData.TRANSACTION_PROVIDER + "='" + txProvider + "'");
@@ -87,18 +94,18 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
         Properties props = PropertiesUtil.deepCopy(TEST_PROPERTIES);
         return getConnection(props);
     }
-    
-    @Parameters(name="MutableIndexIT_localIndex={0},transactionProvider={1},columnEncoded={2}") // name is used by failsafe as file name in reports
+
+    // name is used by failsafe as file name in reports
+    @Parameters(name="MutableIndexIT_localIndex={0},transactionProvider={1},columnEncoded={2}")
     public static synchronized Collection<Object[]> data() {
-        return TestUtil.filterTxParamData(Arrays.asList(new Object[][] { 
-                { false, null, false }, { false, null, true },
-                { false, "TEPHRA", false }, { false, "TEPHRA", true },
-                { false, "OMID", false },
-                { true, null, false }, { true, null, true },
-                { true, "TEPHRA", false }, { true, "TEPHRA", true },
-                }),1);
+        return Arrays.asList(new Object[][] {
+            { false, null, false }, { false, null, true },
+            // OMID does not support local indexes or column encoding
+            { false, "OMID", false },
+            { true, null, false }, { true, null, true },
+        });
     }
-    
+
     @Test
     public void testCoveredColumnUpdates() throws Exception {
         try (Connection conn = getConnection()) {
@@ -116,7 +123,9 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
             String query = "SELECT char_col1, int_col1, long_col2 from " + fullTableName;
             ResultSet rs = conn.createStatement().executeQuery("EXPLAIN " + query);
             if (localIndex) {
-                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullTableName +" [1]\nCLIENT MERGE SORT", QueryUtil.getExplainPlan(rs));
+                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullIndexName +
+                        "(" + fullTableName + ") [1]\nCLIENT MERGE SORT",
+                        QueryUtil.getExplainPlan(rs));
             } else {
                 assertEquals("CLIENT PARALLEL 1-WAY FULL SCAN OVER " + fullIndexName, QueryUtil.getExplainPlan(rs));
             }
@@ -183,7 +192,8 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
             if(localIndex) {
                 query = "SELECT b.* from " + fullTableName + " where int_col1 = 4 AND char_col1 = 'chara'";
                 rs = conn.createStatement().executeQuery("EXPLAIN " + query);
-                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullTableName +" [1,'chara',4]\n" +
+                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullIndexName +
+                                "(" + fullTableName + ") [1,'chara',4]\n" +
                         "    SERVER MERGE [B.VARCHAR_COL2, B.CHAR_COL2, B.INT_COL2, B.DECIMAL_COL2, B.DATE_COL]\n" +
                         "CLIENT MERGE SORT", QueryUtil.getExplainPlan(rs));
                 rs = conn.createStatement().executeQuery(query);
@@ -284,7 +294,9 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
             query = "SELECT * FROM " + fullTableName;
             rs = conn.createStatement().executeQuery("EXPLAIN " + query);
             if(localIndex) {
-                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullTableName+" [1]\nCLIENT MERGE SORT", QueryUtil.getExplainPlan(rs));            
+                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullIndexName +
+                        "(" + fullTableName + ") [1]\nCLIENT MERGE SORT",
+                        QueryUtil.getExplainPlan(rs));
             } else {
                 assertEquals("CLIENT PARALLEL 1-WAY FULL SCAN OVER " + fullIndexName, QueryUtil.getExplainPlan(rs));
             }
@@ -305,7 +317,9 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
             query = "SELECT * FROM " + fullTableName;
             rs = conn.createStatement().executeQuery("EXPLAIN " + query);
             if(localIndex) {
-                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullTableName + " [1]\nCLIENT MERGE SORT", QueryUtil.getExplainPlan(rs));            
+                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " +
+                        fullIndexName + "(" + fullTableName + ") [1]\nCLIENT MERGE SORT",
+                        QueryUtil.getExplainPlan(rs));
             } else {
                 assertEquals("CLIENT PARALLEL 1-WAY FULL SCAN OVER " + fullIndexName, QueryUtil.getExplainPlan(rs));
             }
@@ -326,7 +340,9 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
             query = "SELECT * FROM " + fullTableName;
             rs = conn.createStatement().executeQuery("EXPLAIN " + query);
             if(localIndex) {
-                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullTableName+" [1]\nCLIENT MERGE SORT", QueryUtil.getExplainPlan(rs));            
+                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullIndexName +
+                        "(" + fullTableName + ") [1]\nCLIENT MERGE SORT",
+                        QueryUtil.getExplainPlan(rs));
             } else {
                 assertEquals("CLIENT PARALLEL 1-WAY FULL SCAN OVER " + fullIndexName, QueryUtil.getExplainPlan(rs));
             }
@@ -394,12 +410,15 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
             query = "SELECT * FROM " + fullTableName;
             rs = conn.createStatement().executeQuery("EXPLAIN " + query);
             if (localIndex) {
-                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullTableName+" [1]\n"
-                        + "    SERVER FILTER BY FIRST KEY ONLY\n"
+                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullIndexName +
+                        "(" + fullTableName + ") [1]\n"
+                        + "    SERVER FILTER BY " + (columnEncoded ? "FIRST KEY" :  "EMPTY COLUMN") + " ONLY\n"
                         + "CLIENT MERGE SORT", QueryUtil.getExplainPlan(rs));
             } else {
                 assertEquals("CLIENT PARALLEL 1-WAY FULL SCAN OVER " + fullIndexName + "\n"
-                           + "    SERVER FILTER BY FIRST KEY ONLY", QueryUtil.getExplainPlan(rs));
+                           + "    SERVER FILTER BY " +
+                        (columnEncoded ? "FIRST KEY" :  "EMPTY COLUMN") + " ONLY",
+                        QueryUtil.getExplainPlan(rs));
             }
             //make sure the data table looks like what we expect
             rs = conn.createStatement().executeQuery(query);
@@ -521,13 +540,14 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
             query = "SELECT * FROM " + fullTableName;
             rs = conn.createStatement().executeQuery("EXPLAIN " + query);
             if(localIndex) {
-                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullTableName+" [1]\n"
-                        + "    SERVER FILTER BY FIRST KEY ONLY\n"
+                assertEquals("CLIENT PARALLEL 1-WAY RANGE SCAN OVER " + fullIndexName +
+                                "(" + fullTableName + ") [1]\n"
+                        + "    SERVER FILTER BY " + (columnEncoded ? "FIRST KEY" :  "EMPTY COLUMN") + " ONLY\n"
                         + "CLIENT MERGE SORT",
                     QueryUtil.getExplainPlan(rs));
             } else {
                 assertEquals("CLIENT PARALLEL 1-WAY FULL SCAN OVER " + fullIndexName + "\n"
-                        + "    SERVER FILTER BY FIRST KEY ONLY",
+                        + "    SERVER FILTER BY " + (columnEncoded ? "FIRST KEY" :  "EMPTY COLUMN") + " ONLY",
                     QueryUtil.getExplainPlan(rs));
             }
         
@@ -739,8 +759,8 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
           assertEquals(1, rs.getInt(2));
           assertEquals(0.5F, rs.getFloat(1), 0.0);
           assertEquals("foo", rs.getString(3));
-      } 
-  }
+      }
+    }
 
     @Test
     public void testUpsertingDeletedRowWithNullCoveredColumn() throws Exception {
@@ -813,7 +833,7 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
           // PHOENIX-4980
           // When there is a flush after a data table update of non-indexed columns, the
           // index gets out of sync on the next write
-          getUtility().getHBaseAdmin().flush(TableName.valueOf(fullTableName));
+          getUtility().getAdmin().flush(TableName.valueOf(fullTableName));
           conn.createStatement().executeUpdate("UPSERT INTO " + fullTableName + "(k,v1,v2) VALUES ('testKey','v1_4','v2_3')");
           conn.commit();
           IndexScrutiny.scrutinizeIndex(conn, fullTableName, fullIndexName);
@@ -919,6 +939,25 @@ public class MutableIndexIT extends ParallelStatsDisabledIT {
         }
     }
 
+    @Test
+    public void testCreateIndexSchemaVersion() throws Exception {
+        Properties props = new Properties();
+        final String schemaName = generateUniqueName();
+        final String tableName = generateUniqueName();
+        final String indexName = generateUniqueName();
+        final String dataTableFullName = SchemaUtil.getTableName(schemaName, tableName);
+        final String indexFullName = SchemaUtil.getTableName(schemaName, indexName);
+        try (PhoenixConnection conn = (PhoenixConnection) DriverManager.getConnection(getUrl(), props)) {
+            String version = "V1.0";
+            CreateTableIT.testCreateTableSchemaVersionAndTopicNameHelper(conn, schemaName, tableName, version, null);
+            String createIndexSql = "CREATE INDEX " + indexName + " ON " + dataTableFullName +
+                    " (ID2) INCLUDE (ID1) SCHEMA_VERSION='" + version + "'";
+            conn.createStatement().execute(createIndexSql);
+            PTable index = conn.getTableNoCache( indexFullName);
+            assertEquals(version, index.getSchemaVersion());
+        }
+    }
+
 private void upsertRow(String dml, Connection tenantConn, int i) throws SQLException {
     PreparedStatement stmt = tenantConn.prepareStatement(dml);
       stmt.setString(1, "00000000000000" + String.valueOf(i));
