@@ -136,10 +136,11 @@ public class SchemaToolExtractionIT extends ParallelStatsEnabledIT {
         List<String> queries = new ArrayList<String>(){};
         queries.add(createTableStatement);
         queries.add(createIndexStatement);
-        try (Connection conn = DriverManager.getConnection(getUrl(), props)) {
+        try (PhoenixConnection conn = DriverManager.getConnection(getUrl(), props)
+                .unwrap(PhoenixConnection.class)) {
             executeCreateStatements(conn, queries);
-            PTable pData = PhoenixRuntime.getTable(conn, pTableFullName);
-            PTable pIndex = PhoenixRuntime.getTable(conn, pIndexFullName);
+            PTable pData = conn.getTable(pTableFullName);
+            PTable pIndex = conn.getTable(pIndexFullName);
             SchemaExtractionProcessor schemaExtractionProcessor = new SchemaExtractionProcessor(null, config, pData, true);
             String tableDDL = schemaExtractionProcessor.process();
             assertTrue(tableDDL.contains("IMMUTABLE_STORAGE_SCHEME"));
@@ -417,7 +418,8 @@ public class SchemaToolExtractionIT extends ParallelStatsEnabledIT {
                 "(a_char CHAR(15) NOT NULL, " +
                 "b_char CHAR(10) NOT NULL, " +
                 "c_var_array VARCHAR ARRAY, " +
-                "d_char_array CHAR(15) ARRAY[3] CONSTRAINT PK PRIMARY KEY (a_char, b_char)) " +
+                "d_char_array CHAR(15) ARRAY[3] " +
+                "CONSTRAINT PK PRIMARY KEY (a_char, b_char)) " +
                 "TTL=2592000, IMMUTABLE_STORAGE_SCHEME='ONE_CELL_PER_COLUMN', REPLICATION_SCOPE=1";
         List<String> queries = new ArrayList<String>(){};
         queries.add(query);
@@ -458,7 +460,8 @@ public class SchemaToolExtractionIT extends ParallelStatsEnabledIT {
                 "b_char CHAR(10) NOT NULL, " +
                 "\"av\".\"_\" CHAR(1), " +
                 "\"bv\".\"_\" CHAR(1), " +
-                "\"cv\".\"_\" CHAR(1) CONSTRAINT PK PRIMARY KEY (a_char, b_char)) " + properties;
+                "\"cv\".\"_\" CHAR(1) " +
+                "CONSTRAINT PK PRIMARY KEY (a_char, b_char)) " + properties;
         List<String> queries = new ArrayList<String>(){};
         queries.add(query);
         String result = runSchemaExtractionTool(schemaName, tableName, null, queries);
