@@ -31,7 +31,7 @@ import org.apache.phoenix.schema.SortOrder;
 import org.apache.phoenix.schema.types.*;
 import org.junit.Test;
 
-import com.google.common.collect.Lists;
+import org.apache.phoenix.thirdparty.com.google.common.collect.Lists;
 
 public class ArrayAppendFunctionTest {
 
