@@ -52,15 +52,15 @@ public class TestApplyAndFilterDeletesFilter {
   public void testDeletesAreNotReturned() {
     KeyValue kv = createKvForType(Type.Delete);
     ApplyAndFilterDeletesFilter filter = new ApplyAndFilterDeletesFilter(EMPTY_SET);
-    assertEquals("Didn't skip point delete!", ReturnCode.SKIP, filter.filterKeyValue(kv));
+    assertEquals("Didn't skip point delete!", ReturnCode.SKIP, filter.filterCell(kv));
 
     filter.reset();
     kv = createKvForType(Type.DeleteColumn);
-    assertEquals("Didn't skip from column delete!", ReturnCode.SKIP, filter.filterKeyValue(kv));
+    assertEquals("Didn't skip from column delete!", ReturnCode.SKIP, filter.filterCell(kv));
 
     filter.reset();
     kv = createKvForType(Type.DeleteFamily);
-    assertEquals("Didn't skip from family delete!", ReturnCode.SKIP, filter.filterKeyValue(kv));
+    assertEquals("Didn't skip from family delete!", ReturnCode.SKIP, filter.filterCell(kv));
   }
 
   /**
@@ -72,30 +72,30 @@ public class TestApplyAndFilterDeletesFilter {
     // start with doing a family delete, so we will seek to the next column
     KeyValue kv = createKvForType(Type.DeleteFamily);
     ApplyAndFilterDeletesFilter filter = new ApplyAndFilterDeletesFilter(EMPTY_SET);
-    assertEquals(ReturnCode.SKIP, filter.filterKeyValue(kv));
+    assertEquals(ReturnCode.SKIP, filter.filterCell(kv));
     KeyValue next = createKvForType(Type.Put);
     // make sure the hint is our attempt at the end key, because we have no more families to seek
     assertEquals("Didn't get a hint from a family delete", ReturnCode.SEEK_NEXT_USING_HINT,
-      filter.filterKeyValue(next));
+      filter.filterCell(next));
     assertEquals("Didn't get END_KEY with no families to match", KeyValue.LOWESTKEY,
       filter.getNextCellHint(next));
 
     // check for a family that comes before our family, so we always seek to the end as well
     filter = new ApplyAndFilterDeletesFilter(asSet(Bytes.toBytes("afamily")));
-    assertEquals(ReturnCode.SKIP, filter.filterKeyValue(kv));
+    assertEquals(ReturnCode.SKIP, filter.filterCell(kv));
     // make sure the hint is our attempt at the end key, because we have no more families to seek
     assertEquals("Didn't get a hint from a family delete", ReturnCode.SEEK_NEXT_USING_HINT,
-      filter.filterKeyValue(next));
+      filter.filterCell(next));
     assertEquals("Didn't get END_KEY with no families to match", KeyValue.LOWESTKEY,
       filter.getNextCellHint(next));
 
     // check that we seek to the correct family that comes after our family
     byte[] laterFamily = Bytes.toBytes("zfamily");
     filter = new ApplyAndFilterDeletesFilter(asSet(laterFamily));
-    assertEquals(ReturnCode.SKIP, filter.filterKeyValue(kv));
+    assertEquals(ReturnCode.SKIP, filter.filterCell(kv));
     KeyValue expected = KeyValueUtil.createFirstOnRow(CellUtil.cloneRow(kv), laterFamily, new byte[0]);
     assertEquals("Didn't get a hint from a family delete", ReturnCode.SEEK_NEXT_USING_HINT,
-      filter.filterKeyValue(next));
+      filter.filterCell(next));
     assertEquals("Didn't get correct next key with a next family", expected,
       filter.getNextCellHint(next));
   }
@@ -109,20 +109,20 @@ public class TestApplyAndFilterDeletesFilter {
     // start with doing a family delete, so we will seek to the next column
     KeyValue kv = createKvForType(Type.Delete);
     ApplyAndFilterDeletesFilter filter = new ApplyAndFilterDeletesFilter(EMPTY_SET);
-    filter.filterKeyValue(kv);
+    filter.filterCell(kv);
     KeyValue put = createKvForType(Type.Put);
     assertEquals("Didn't filter out put with same timestamp!", ReturnCode.SKIP,
-      filter.filterKeyValue(put));
+      filter.filterCell(put));
     // we should filter out the exact same put again, which could occur with the kvs all kept in the
     // same memstore
     assertEquals("Didn't filter out put with same timestamp on second call!", ReturnCode.SKIP,
-      filter.filterKeyValue(put));
+      filter.filterCell(put));
 
     // ensure then that we don't filter out a put with an earlier timestamp (though everything else
     // matches)
     put = createKvForType(Type.Put, ts - 1);
     assertEquals("Didn't accept put that has an earlier ts than the covering delete!",
-      ReturnCode.INCLUDE, filter.filterKeyValue(put));
+      ReturnCode.INCLUDE, filter.filterCell(put));
   }
 
   private KeyValue createKvForType(Type t) {
@@ -142,9 +142,9 @@ public class TestApplyAndFilterDeletesFilter {
     ApplyAndFilterDeletesFilter filter = new ApplyAndFilterDeletesFilter(EMPTY_SET);
     KeyValue dc = createKvForType(Type.DeleteColumn, 11);
     KeyValue put = createKvForType(Type.Put, 10);
-    assertEquals("Didn't filter out delete column.", ReturnCode.SKIP, filter.filterKeyValue(dc));
+    assertEquals("Didn't filter out delete column.", ReturnCode.SKIP, filter.filterCell(dc));
     assertEquals("Didn't get a seek hint for the deleted column", ReturnCode.SEEK_NEXT_USING_HINT,
-      filter.filterKeyValue(put));
+      filter.filterCell(put));
     // seek past the given put
     Cell seek = filter.getNextCellHint(put);
     assertTrue("Seeked key wasn't past the expected put - didn't skip the column",
@@ -161,14 +161,14 @@ public class TestApplyAndFilterDeletesFilter {
     KeyValue df = createKvForType(Type.DeleteFamily, 11);
     KeyValue put = createKvForType(Type.Put, 12);
 
-    assertEquals("Didn't filter out delete family", ReturnCode.SKIP, filter.filterKeyValue(df));
+    assertEquals("Didn't filter out delete family", ReturnCode.SKIP, filter.filterCell(df));
     assertEquals("Filtered out put with newer TS than delete family", ReturnCode.INCLUDE,
-      filter.filterKeyValue(put));
+      filter.filterCell(put));
 
     // older kv shouldn't be visible
     put = createKvForType(Type.Put, 10);
     assertEquals("Didn't filter out older put, covered by DeleteFamily marker",
-      ReturnCode.SEEK_NEXT_USING_HINT, filter.filterKeyValue(put));
+      ReturnCode.SEEK_NEXT_USING_HINT, filter.filterCell(put));
 
     // next seek should be past the families
     assertEquals(KeyValue.LOWESTKEY, filter.getNextCellHint(put));
@@ -184,20 +184,20 @@ public class TestApplyAndFilterDeletesFilter {
     byte[] qual2 = Bytes.add(qualifier, Bytes.toBytes("-other"));
     KeyValue put = new KeyValue(row, family, qual2, 11, Type.Put, value);
 
-    assertEquals("Didn't filter out delete column", ReturnCode.SKIP, filter.filterKeyValue(d));
+    assertEquals("Didn't filter out delete column", ReturnCode.SKIP, filter.filterCell(d));
     // different column put should still be visible
     assertEquals("Filtered out put with different column than the delete", ReturnCode.INCLUDE,
-      filter.filterKeyValue(put));
+      filter.filterCell(put));
 
     // set a delete family, but in the past
     d = createKvForType(Type.DeleteFamily, 10);
-    assertEquals("Didn't filter out delete column", ReturnCode.SKIP, filter.filterKeyValue(d));
+    assertEquals("Didn't filter out delete column", ReturnCode.SKIP, filter.filterCell(d));
     // add back in the original delete column
     d = createKvForType(Type.DeleteColumn, 11);
-    assertEquals("Didn't filter out delete column", ReturnCode.SKIP, filter.filterKeyValue(d));
+    assertEquals("Didn't filter out delete column", ReturnCode.SKIP, filter.filterCell(d));
     // onto a different family, so that must be visible too
     assertEquals("Filtered out put with different column than the delete", ReturnCode.INCLUDE,
-      filter.filterKeyValue(put));
+      filter.filterCell(put));
   }
 
   private static Set<ImmutableBytesPtr> asSet(byte[]... strings) {
