@@ -18,16 +18,13 @@
 package org.apache.phoenix.index;
 
 import org.apache.phoenix.thirdparty.org.apache.commons.cli.CommandLine;
-import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
 import org.apache.phoenix.end2end.IndexToolIT;
 import org.apache.phoenix.mapreduce.index.IndexScrutinyTool;
 import org.apache.phoenix.mapreduce.index.IndexTool;
 import org.apache.phoenix.query.BaseTest;
 import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.util.EnvironmentEdgeManager;
-import org.apache.phoenix.util.IndexScrutiny;
 import org.junit.Assert;
-import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
@@ -40,7 +37,6 @@ import static org.apache.phoenix.mapreduce.index.IndexTool.FEATURE_NOT_APPLICABL
 import static org.apache.phoenix.mapreduce.index.IndexTool.INVALID_TIME_RANGE_EXCEPTION_MESSAGE;
 import static org.apache.phoenix.mapreduce.index.IndexTool.RETRY_VERIFY_NOT_APPLICABLE;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assume.assumeTrue;
 import static org.mockito.Mockito.when;
 
 public class IndexToolTest extends BaseTest {
@@ -69,7 +65,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test
     public void testParseOptions_timeRange_timeRangeNotNull() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         Long startTime = 10L;
         Long endTime = 15L;
         String [] args =
@@ -95,7 +90,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test
     public void testParseOptions_timeRange_startTimeNotNull() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         Long startTime = 10L;
         String [] args =
                 IndexToolIT.getArgValues(true, schema,
@@ -135,7 +129,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test
     public void testParseOptions_timeRange_endTimeNullStartTimeInFuture() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         Long startTime = EnvironmentEdgeManager.currentTimeMillis() + 100000;
         String [] args =
                 IndexToolIT.getArgValues(true, schema,
@@ -149,7 +142,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test(timeout = 10000 /* 10 secs */)
     public void testParseOptions_timeRange_startTimeInFuture() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         Long startTime = EnvironmentEdgeManager.currentTimeMillis() + 100000;
         Long endTime = EnvironmentEdgeManager.currentTimeMillis() + 200000;
         String [] args =
@@ -164,7 +156,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test(timeout = 10000 /* 10 secs */)
     public void testParseOptions_timeRange_endTimeInFuture() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         Long startTime = EnvironmentEdgeManager.currentTimeMillis();
         Long endTime = EnvironmentEdgeManager.currentTimeMillis() + 100000;
         String [] args =
@@ -179,7 +170,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test
     public void testParseOptions_timeRange_startTimeEqEndTime() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         Long startTime = 10L;
         Long endTime = 10L;
         String [] args =
@@ -194,7 +184,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test
     public void testParseOptions_timeRange_startTimeGtEndTime() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         Long startTime = 10L;
         Long endTime = 1L;
         String [] args =
@@ -217,7 +206,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test
     public void testIncrcementalVerifyOption() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         IndexTool mockTool = Mockito.mock(IndexTool.class);
         when(mockTool.getLastVerifyTime()).thenCallRealMethod();
         Long lastVerifyTime = 10L;
@@ -243,7 +231,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test
     public void testIncrcementalVerifyOption_notApplicable() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         IndexTool mockTool = Mockito.mock(IndexTool.class);
         when(mockTool.getLastVerifyTime()).thenCallRealMethod();
         Long lastVerifyTime = 10L;
@@ -265,39 +252,6 @@ public class IndexToolTest extends BaseTest {
         mockTool.populateIndexToolAttributes(cmdLine);
     }
 
-    @Test
-    public void testIncrementalVerifyNotSupportedWithoutRawSkipScanFilters() {
-        //We should give an exception if we try to use incremental verification on HBase 2.1
-        // which lacks HBASE-22710 enabling raw skip scan filters. For 2.2 we assume 2.2.5+
-        Assume.assumeFalse(HbaseCompatCapabilities.isRawFilterSupported());
-        try {
-            IndexTool it = new IndexTool();
-            Long lastVerifyTime = 10L;
-            String[] args =
-                IndexToolIT.getArgValues(true, schema,
-                    dataTable, indexTable, tenantId, IndexTool.IndexVerifyType.AFTER,
-                    lastVerifyTime, null, IndexTool.IndexDisableLoggingType.NONE,
-                    lastVerifyTime);
-            it.parseOptions(args);
-            Assert.fail("Should have thrown an IllegalStateException");
-        } catch (IllegalStateException ise) {
-            //eat exception
-        }
-        //now check retry-verify
-        try {
-            IndexTool it = new IndexTool();
-            Long lastVerifyTime = 10L;
-            String[] args =
-                IndexToolIT.getArgValues(true, schema,
-                    dataTable, indexTable, tenantId, IndexTool.IndexVerifyType.AFTER,
-                    null, null, IndexTool.IndexDisableLoggingType.NONE,
-                    lastVerifyTime);
-            it.parseOptions(args);
-            Assert.fail("Should have thrown an IllegalStateException");
-        } catch (IllegalStateException ise) {
-            //eat exception
-        }
-    }
     @Test
     public void testCheckVerifyAndDisableLogging_defaultsNone() throws Exception {
         Long startTime = null;
@@ -383,7 +337,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test
     public void testIndexToolDefaultSource() throws Exception {
-        assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         Long startTime = 1L;
         Long endTime = 10L;
         String [] args =
@@ -397,7 +350,6 @@ public class IndexToolTest extends BaseTest {
 
     @Test
     public void testIndexToolFromIndexSource() throws Exception {
-        assumeTrue(HbaseCompatCapabilities.isRawFilterSupported());
         verifyFromIndexOption(IndexTool.IndexVerifyType.ONLY);
         verifyFromIndexOption(IndexTool.IndexVerifyType.BEFORE);
     }
