@@ -31,11 +31,9 @@ import org.apache.hadoop.hbase.client.Put;
 import org.apache.hadoop.hbase.client.Result;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.hadoop.hbase.util.Pair;
-import org.apache.phoenix.compat.hbase.HbaseCompatCapabilities;
 import org.apache.phoenix.coprocessor.GlobalIndexRegionScanner;
 import org.apache.phoenix.coprocessor.IndexRebuildRegionScanner;
 import org.apache.phoenix.coprocessor.IndexToolVerificationResult;
-import org.apache.phoenix.hbase.index.IndexRegionObserver;
 import org.apache.phoenix.jdbc.PhoenixConnection;
 import org.apache.phoenix.mapreduce.index.IndexVerificationOutputRepository;
 import org.apache.phoenix.query.BaseConnectionlessQueryTest;
@@ -43,12 +41,12 @@ import org.apache.phoenix.query.QueryConstants;
 import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTableKey;
 import org.apache.phoenix.util.*;
-import org.junit.Assume;
+import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.rules.ExpectedException;
-import org.mockito.Matchers;
+import org.mockito.ArgumentMatchers;
 import org.mockito.Mock;
 import org.mockito.Mockito;
 import org.mockito.MockitoAnnotations;
@@ -65,7 +63,7 @@ import static org.apache.phoenix.query.QueryConstants.UNVERIFIED_BYTES;
 import static org.apache.phoenix.query.QueryConstants.VERIFIED_BYTES;
 import static org.apache.phoenix.query.QueryConstants.EMPTY_COLUMN_BYTES;
 import static org.junit.Assert.*;
-import static org.mockito.Matchers.any;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doNothing;
 import static org.mockito.Mockito.when;
 
@@ -150,6 +148,11 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
         initializeGlobalMockitoSetup();
     }
 
+    @After
+    public void reset() {
+        EnvironmentEdgeManager.reset();
+    }
+
     public void createDBObject() throws SQLException {
         try(Connection conn = DriverManager.getConnection(getUrl(), new Properties())) {
             schema = generateUniqueName();
@@ -268,10 +271,10 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
         }
     }
 
-    private void initializeRebuildScannerAttributes() {
-        when(rebuildScanner.setIndexTableTTL(Matchers.anyInt())).thenCallRealMethod();
-        when(rebuildScanner.setIndexMaintainer(Matchers.<IndexMaintainer>any())).thenCallRealMethod();
-        when(rebuildScanner.setMaxLookBackInMills(Matchers.anyLong())).thenCallRealMethod();
+    private void initializeRebuildScannerAttributes() throws SQLException {
+        when(rebuildScanner.setIndexTableTTL(ArgumentMatchers.anyInt())).thenCallRealMethod();
+        when(rebuildScanner.setIndexMaintainer(ArgumentMatchers.<IndexMaintainer>any())).thenCallRealMethod();
+        when(rebuildScanner.setMaxLookBackInMills(ArgumentMatchers.anyLong())).thenCallRealMethod();
         rebuildScanner.setIndexTableTTL(HConstants.FOREVER);
         indexMaintainer = pIndexTable.getIndexMaintainer(pDataTable, pconn);
         rebuildScanner.setIndexMaintainer(indexMaintainer);
@@ -281,19 +284,19 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
 
     private void initializeGlobalMockitoSetup() throws IOException {
         //setup
-        when(GlobalIndexRegionScanner.getIndexRowKey(indexMaintainer, put)).thenCallRealMethod();
+        when(indexMaintainer.getIndexRowKey(put)).thenCallRealMethod();
         when(rebuildScanner.prepareIndexMutations(put, delete, indexKeyToMutationMap, mostRecentIndexRowKeys)).thenCallRealMethod();
-        when(rebuildScanner.verifySingleIndexRow(Matchers.<byte[]>any(), Matchers.<List>any(),Matchers.<List>any(), Matchers.<Set>any(), Matchers.<List>any(),
-                Matchers.<IndexToolVerificationResult.PhaseResult>any(), Matchers.anyBoolean())).thenCallRealMethod();
+        when(rebuildScanner.verifySingleIndexRow(ArgumentMatchers.<byte[]>any(), ArgumentMatchers.<List>any(),ArgumentMatchers.<List>any(), ArgumentMatchers.<Set>any(), ArgumentMatchers.<List>any(),
+                ArgumentMatchers.<IndexToolVerificationResult.PhaseResult>any(), ArgumentMatchers.anyBoolean())).thenCallRealMethod();
         doNothing().when(rebuildScanner)
-                .logToIndexToolOutputTable(Matchers.<byte[]>any(),Matchers.<byte[]>any(),
+                .logToIndexToolOutputTable(ArgumentMatchers.<byte[]>any(),ArgumentMatchers.<byte[]>any(),
                         Mockito.anyLong(),Mockito.anyLong(), Mockito.anyString(),
-                        Matchers.<byte[]>any(), Matchers.<byte[]>any(), Matchers.anyBoolean(),
+                        ArgumentMatchers.<byte[]>any(), ArgumentMatchers.<byte[]>any(), ArgumentMatchers.anyBoolean(),
                     Mockito.<IndexVerificationOutputRepository.IndexVerificationErrorType>any());
         doNothing().when(rebuildScanner)
-                .logToIndexToolOutputTable(Matchers.<byte[]>any(),Matchers.<byte[]>any(),
+                .logToIndexToolOutputTable(ArgumentMatchers.<byte[]>any(),ArgumentMatchers.<byte[]>any(),
                         Mockito.anyLong(),Mockito.anyLong(), Mockito.anyString(),
-                    Matchers.anyBoolean(),
+                    ArgumentMatchers.anyBoolean(),
                     Mockito.<IndexVerificationOutputRepository.IndexVerificationErrorType>any());
 
         //populate the local map to use to create actual mutations
@@ -471,7 +474,6 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
     // We will report such row as a valid row.
     @Test
     public void testVerifySingleIndexRow_compactionOnIndexTable_atLeastOneExpectedMutationWithinMaxLookBack() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isMaxLookbackTimeSupported());
         String dataRowKey = "k1";
         byte[] indexRowKey1Bytes = generateIndexRowKey(dataRowKey, "val1");
         ManualEnvironmentEdge injectEdge = new ManualEnvironmentEdge();
@@ -531,7 +533,6 @@ public class VerifySingleIndexRowTest extends BaseConnectionlessQueryTest {
     // We will report such row as an invalid beyond maxLookBack row.
     @Test
     public void testVerifySingleIndexRow_compactionOnIndexTable_noExpectedMutationWithinMaxLookBack() throws Exception {
-        Assume.assumeTrue(HbaseCompatCapabilities.isMaxLookbackTimeSupported());
         String dataRowKey = "k1";
         byte[] indexRowKey1Bytes = generateIndexRowKey(dataRowKey, "val1");
         List<Mutation> expectedMutations = new ArrayList<>();
