@@ -17,11 +17,6 @@
  */
 package org.apache.phoenix.mapreduce;
 
-import org.apache.hadoop.conf.Configuration;
-import org.apache.hadoop.mapred.JobContext;
-import org.junit.Test;
-import org.mockito.Mockito;
-
 import static junit.framework.TestCase.assertTrue;
 import static junit.framework.TestCase.fail;
 import static org.apache.phoenix.mapreduce.util.
@@ -30,16 +25,33 @@ import static org.apache.phoenix.mapreduce.util.
         PhoenixConfigurationUtil.MAPREDUCE_MULTI_INPUT_SPLIT_STRATEGY_CLAZZ;
 import static org.apache.phoenix.mapreduce.util.
         PhoenixConfigurationUtil.MAPREDUCE_MULTI_INPUT_STRATEGY_CLAZZ;
+import static org.apache.phoenix.util.PhoenixRuntime.CONNECTIONLESS;
+import static org.apache.phoenix.util.PhoenixRuntime.JDBC_PROTOCOL_SEPARATOR;
+import static org.apache.phoenix.util.PhoenixRuntime.JDBC_PROTOCOL_TERMINATOR;
+import static org.apache.phoenix.util.PhoenixRuntime.JDBC_PROTOCOL_ZK;
+import static org.apache.phoenix.util.PhoenixRuntime.PHOENIX_TEST_DRIVER_URL_PARAM;
 import static org.mockito.Mockito.when;
 
+import org.apache.hadoop.conf.Configuration;
+import org.apache.hadoop.mapred.JobContext;
+import org.apache.phoenix.mapreduce.util.PhoenixConfigurationUtil;
+import org.junit.Test;
+import org.mockito.Mockito;
+
+
 public class PhoenixMultiViewInputFormatTest {
 
+    private static String CONNECTIONLESS_URL =
+            JDBC_PROTOCOL_ZK + JDBC_PROTOCOL_SEPARATOR + CONNECTIONLESS + JDBC_PROTOCOL_TERMINATOR
+                    + PHOENIX_TEST_DRIVER_URL_PARAM + JDBC_PROTOCOL_TERMINATOR;
+
     @Test
     public void testDefaultConfig() throws Exception {
         PhoenixMultiViewInputFormat multiViewInputFormat = new PhoenixMultiViewInputFormat();
 
         Configuration config = new Configuration();
         config.set(MAPREDUCE_MULTI_INPUT_MAPPER_SPLIT_SIZE, "10");
+        PhoenixConfigurationUtil.setInputClusterUrl(config, CONNECTIONLESS_URL);
         JobContext mockContext = Mockito.mock(JobContext.class);
         when(mockContext.getConfiguration()).thenReturn(config);
 
@@ -55,6 +67,7 @@ public class PhoenixMultiViewInputFormatTest {
         Configuration config = new Configuration();
         config.set(MAPREDUCE_MULTI_INPUT_MAPPER_SPLIT_SIZE, "10");
         config.set(MAPREDUCE_MULTI_INPUT_STRATEGY_CLAZZ, "dummy.path");
+        PhoenixConfigurationUtil.setInputClusterUrl(config, CONNECTIONLESS_URL);
         JobContext mockContext = Mockito.mock(JobContext.class);
         when(mockContext.getConfiguration()).thenReturn(config);
 
@@ -73,6 +86,7 @@ public class PhoenixMultiViewInputFormatTest {
         Configuration config = new Configuration();
         config.set(MAPREDUCE_MULTI_INPUT_MAPPER_SPLIT_SIZE, "10");
         config.set(MAPREDUCE_MULTI_INPUT_SPLIT_STRATEGY_CLAZZ, "dummy.path");
+        PhoenixConfigurationUtil.setInputClusterUrl(config, CONNECTIONLESS_URL);
         JobContext mockContext = Mockito.mock(JobContext.class);
         when(mockContext.getConfiguration()).thenReturn(config);
 
