@@ -119,9 +119,9 @@ import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.hbase.HBaseConfiguration;
 import org.apache.hadoop.hbase.HBaseTestingUtility;
 import org.apache.hadoop.hbase.HConstants;
-import org.apache.hadoop.hbase.HRegionInfo;
 import org.apache.hadoop.hbase.IntegrationTestingUtility;
 import org.apache.hadoop.hbase.MiniHBaseCluster;
+import org.apache.hadoop.hbase.RegionMetrics;
 import org.apache.hadoop.hbase.ServerName;
 import org.apache.hadoop.hbase.TableName;
 import org.apache.hadoop.hbase.client.Admin;
@@ -135,7 +135,6 @@ import org.apache.hadoop.hbase.regionserver.HRegionServer;
 import org.apache.hadoop.hbase.regionserver.RSRpcServices;
 import org.apache.hadoop.hbase.util.Bytes;
 import org.apache.phoenix.SystemExitRule;
-import org.apache.phoenix.compat.hbase.CompatUtil;
 import org.apache.phoenix.end2end.NeedsOwnMiniClusterTest;
 import org.apache.phoenix.end2end.ParallelStatsDisabledIT;
 import org.apache.phoenix.end2end.ParallelStatsDisabledTest;
@@ -148,6 +147,7 @@ import org.apache.phoenix.jdbc.PhoenixDatabaseMetaData;
 import org.apache.phoenix.jdbc.PhoenixEmbeddedDriver;
 import org.apache.phoenix.jdbc.PhoenixTestDriver;
 import org.apache.phoenix.schema.NewerTableAlreadyExistsException;
+import org.apache.phoenix.schema.PTable;
 import org.apache.phoenix.schema.PTableType;
 import org.apache.phoenix.schema.TableAlreadyExistsException;
 import org.apache.phoenix.schema.TableNotFoundException;
@@ -155,6 +155,7 @@ import org.apache.phoenix.util.ConfigUtil;
 import org.apache.phoenix.util.DateUtil;
 import org.apache.phoenix.util.PhoenixRuntime;
 import org.apache.phoenix.util.PropertiesUtil;
+import org.apache.phoenix.util.QueryBuilder;
 import org.apache.phoenix.util.QueryUtil;
 import org.apache.phoenix.util.ReadOnlyProps;
 import org.apache.phoenix.util.SchemaUtil;
@@ -194,6 +195,7 @@ import org.apache.phoenix.thirdparty.com.google.common.util.concurrent.ThreadFac
 
 public abstract class BaseTest {
     public static final String DRIVER_CLASS_NAME_ATTRIB = "phoenix.driver.class.name";
+    protected static final String NULL_STRING="NULL";
     private static final double ZERO = 1e-9;
     private static final Map<String,String> tableDDLMap;
     private static final Logger LOGGER = LoggerFactory.getLogger(BaseTest.class);
@@ -541,7 +543,8 @@ public abstract class BaseTest {
         utility = new HBaseTestingUtility(conf);
         try {
             long startTime = System.currentTimeMillis();
-            utility.startMiniCluster(NUM_SLAVES_BASE);
+            utility.startMiniCluster(overrideProps.getInt(
+                    QueryServices.TESTS_MINI_CLUSTER_NUM_REGION_SERVERS, NUM_SLAVES_BASE));
             long startupTime = System.currentTimeMillis()-startTime;
             LOGGER.info("HBase minicluster startup complete in {} ms", startupTime);
             return getLocalClusterUrl(utility);
@@ -611,7 +614,6 @@ public abstract class BaseTest {
          */
         conf.setInt(HConstants.REGION_SERVER_HANDLER_COUNT, 5);
         conf.setInt("hbase.regionserver.metahandler.count", 2);
-        conf.setInt(HConstants.MASTER_HANDLER_COUNT, 2);
         conf.setInt("dfs.namenode.handler.count", 2);
         conf.setInt("dfs.namenode.service.handler.count", 2);
         conf.setInt("dfs.datanode.handler.count", 2);
@@ -743,6 +745,12 @@ public abstract class BaseTest {
         createTestTable(url, ddl, splits, ts);
     }
 
+    protected ResultSet executeQuery(Connection conn, QueryBuilder queryBuilder) throws SQLException {
+        PreparedStatement statement = conn.prepareStatement(queryBuilder.build());
+        ResultSet rs = statement.executeQuery();
+        return rs;
+    }
+
     private static AtomicInteger NAME_SUFFIX = new AtomicInteger(0);
     private static final int MAX_SUFFIX_VALUE = 1000000;
 
@@ -782,6 +790,15 @@ public abstract class BaseTest {
         return "S" + Integer.toString(MAX_SEQ_SUFFIX_VALUE + nextName).substring(1);
     }
 
+    public static void assertMetadata(Connection conn, PTable.ImmutableStorageScheme expectedStorageScheme, PTable.QualifierEncodingScheme
+            expectedColumnEncoding, String tableName)
+            throws Exception {
+        PhoenixConnection phxConn = conn.unwrap(PhoenixConnection.class);
+        PTable table = phxConn.getTableNoCache(tableName);
+        assertEquals(expectedStorageScheme, table.getImmutableStorageScheme());
+        assertEquals(expectedColumnEncoding, table.getEncodingScheme());
+    }
+
     public static synchronized void freeResourcesIfBeyondThreshold() throws Exception {
         if (TABLE_COUNTER.get() > TEARDOWN_THRESHOLD) {
             int numTables = TABLE_COUNTER.get();
@@ -931,7 +948,7 @@ public abstract class BaseTest {
                             rs.getString(PhoenixDatabaseMetaData.TABLE_SCHEM),
                             rs.getString(PhoenixDatabaseMetaData.TABLE_NAME));
                     try {
-                        PhoenixRuntime.getTable(conn, fullTableName);
+                        conn.unwrap(PhoenixConnection.class).getTable(fullTableName);
                         fail("The following tables are not deleted that should be:" + getTableNames(rs));
                     } catch (TableNotFoundException e) {
                     }
@@ -1563,9 +1580,9 @@ public abstract class BaseTest {
      */
     protected static synchronized void disableAndDropNonSystemTables() throws Exception {
         if (driver == null) return;
-        Admin admin = driver.getConnectionQueryServices(null, null).getAdmin();
+        Admin admin = driver.getConnectionQueryServices(getUrl(), new Properties()).getAdmin();
         try {
-            TableDescriptor[] tables = admin.listTables();
+            List<TableDescriptor> tables = admin.listTableDescriptors();
             for (TableDescriptor table : tables) {
                 String schemaName = SchemaUtil.getSchemaNameFromFullName(table.getTableName().getName());
                 if (!QueryConstants.SYSTEM_SCHEMA_NAME.equals(schemaName)) {
@@ -1752,25 +1769,26 @@ public abstract class BaseTest {
         String upsert = "UPSERT INTO " + fullTableName
                 + " VALUES(?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
         PreparedStatement stmt = conn.prepareStatement(upsert);
+        //varchar_pk
         stmt.setString(1, firstRowInBatch ? "firstRowInBatch_" : "" + "varchar"+index);
-        stmt.setString(2, "char"+index);
-        stmt.setInt(3, index);
-        stmt.setLong(4, index);
-        stmt.setBigDecimal(5, new BigDecimal(index));
+        stmt.setString(2, "char"+index); // char_pk
+        stmt.setInt(3, index); // int_pk
+        stmt.setLong(4, index); // long_pk
+        stmt.setBigDecimal(5, new BigDecimal(index)); // decimal_pk
         Date date = DateUtil.parseDate("2015-01-01 00:00:00");
-        stmt.setDate(6, date);
-        stmt.setString(7, "varchar_a");
-        stmt.setString(8, "chara");
-        stmt.setInt(9, index+1);
-        stmt.setLong(10, index+1);
-        stmt.setBigDecimal(11, new BigDecimal(index+1));
-        stmt.setDate(12, date);
-        stmt.setString(13, "varchar_b");
-        stmt.setString(14, "charb");
-        stmt.setInt(15, index+2);
-        stmt.setLong(16, index+2);
-        stmt.setBigDecimal(17, new BigDecimal(index+2));
-        stmt.setDate(18, date);
+        stmt.setDate(6, date); // date_pk
+        stmt.setString(7, "varchar_a"); // a.varchar_col1
+        stmt.setString(8, "chara"); // a.char_col1
+        stmt.setInt(9, index+1); // a.int_col1
+        stmt.setLong(10, index+1); // a.long_col1
+        stmt.setBigDecimal(11, new BigDecimal(index+1)); // a.decimal_col1
+        stmt.setDate(12, date); // a.date1
+        stmt.setString(13, "varchar_b"); // b.varchar_col2
+        stmt.setString(14, "charb"); // b.char_col2
+        stmt.setInt(15, index+2); // b.int_col2
+        stmt.setLong(16, index+2); // b.long_col2
+        stmt.setBigDecimal(17, new BigDecimal(index+2)); // b.decimal_col2
+        stmt.setDate(18, date); // b.date2
         stmt.executeUpdate();
     }
 
@@ -1920,7 +1938,7 @@ public abstract class BaseTest {
     /**
      * Returns true if the region contains atleast one of the metadata rows we are interested in
      */
-    protected static boolean regionContainsMetadataRows(HRegionInfo regionInfo,
+    protected static boolean regionContainsMetadataRows(RegionInfo regionInfo,
             List<byte[]> metadataRowKeys) {
         for (byte[] rowKey : metadataRowKeys) {
             if (regionInfo.containsRow(rowKey)) {
@@ -1949,19 +1967,19 @@ public abstract class BaseTest {
         }
         List<RegionInfo> regionInfoList = admin.getRegions(fullTableName);
         assertEquals(splitPoints.size(), regionInfoList.size());
-        HashMap<ServerName, List<HRegionInfo>> serverToRegionsList = Maps.newHashMapWithExpectedSize(NUM_SLAVES_BASE);
+        HashMap<ServerName, List<RegionInfo>> serverToRegionsList = Maps.newHashMapWithExpectedSize(NUM_SLAVES_BASE);
         Deque<ServerName> availableRegionServers = new ArrayDeque<ServerName>(NUM_SLAVES_BASE);
         for (int i=0; i<NUM_SLAVES_BASE; ++i) {
             availableRegionServers.push(util.getHBaseCluster().getRegionServer(i).getServerName());
         }
-        List<HRegionInfo> tableRegions =
-                admin.getTableRegions(fullTableName);
-        for (HRegionInfo hRegionInfo : tableRegions) {
+        List<RegionInfo> tableRegions =
+                admin.getRegions(fullTableName);
+        for (RegionInfo hRegionInfo : tableRegions) {
             // filter on regions we are interested in
             if (regionContainsMetadataRows(hRegionInfo, splitPoints)) {
                 ServerName serverName = am.getRegionStates().getRegionServerOfRegion(hRegionInfo);
                 if (!serverToRegionsList.containsKey(serverName)) {
-                    serverToRegionsList.put(serverName, new ArrayList<HRegionInfo>());
+                    serverToRegionsList.put(serverName, new ArrayList<RegionInfo>());
                 }
                 serverToRegionsList.get(serverName).add(hRegionInfo);
                 availableRegionServers.remove(serverName);
@@ -1969,8 +1987,8 @@ public abstract class BaseTest {
         }
         assertFalse("No region servers available to move regions on to ",
                 availableRegionServers.isEmpty());
-        for (Entry<ServerName, List<HRegionInfo>> entry : serverToRegionsList.entrySet()) {
-            List<HRegionInfo> regions = entry.getValue();
+        for (Entry<ServerName, List<RegionInfo>> entry : serverToRegionsList.entrySet()) {
+            List<RegionInfo> regions = entry.getValue();
             if (regions.size()>1) {
                 for (int i=1; i< regions.size(); ++i) {
                     moveRegion(regions.get(i), entry.getKey(), availableRegionServers.pop());
@@ -1980,12 +1998,12 @@ public abstract class BaseTest {
 
         // verify each region is on its own region server
         tableRegions =
-                admin.getTableRegions(fullTableName);
+                admin.getRegions(fullTableName);
         Set<ServerName> serverNames = Sets.newHashSet();
-        for (HRegionInfo hRegionInfo : tableRegions) {
+        for (RegionInfo regionInfo : tableRegions) {
             // filter on regions we are interested in
-            if (regionContainsMetadataRows(hRegionInfo, splitPoints)) {
-                ServerName serverName = am.getRegionStates().getRegionServerOfRegion(hRegionInfo);
+            if (regionContainsMetadataRows(regionInfo, splitPoints)) {
+                ServerName serverName = am.getRegionStates().getRegionServerOfRegion(regionInfo);
                 if (!serverNames.contains(serverName)) {
                     serverNames.add(serverName);
                 }
@@ -2025,7 +2043,7 @@ public abstract class BaseTest {
     /**
      * Ensures each region of SYSTEM.CATALOG is on a different region server
      */
-    private static void moveRegion(HRegionInfo regionInfo, ServerName srcServerName, ServerName dstServerName) throws Exception  {
+    private static void moveRegion(RegionInfo regionInfo, ServerName srcServerName, ServerName dstServerName) throws Exception  {
         Admin admin = driver.getConnectionQueryServices(getUrl(), TestUtil.TEST_PROPERTIES).getAdmin();
         HBaseTestingUtility util = getUtility();
         MiniHBaseCluster cluster = util.getHBaseCluster();
@@ -2035,7 +2053,7 @@ public abstract class BaseTest {
         HRegionServer dstServer = util.getHBaseCluster().getRegionServer(dstServerName);
         HRegionServer srcServer = util.getHBaseCluster().getRegionServer(srcServerName);
         byte[] encodedRegionNameInBytes = regionInfo.getEncodedNameAsBytes();
-        admin.move(encodedRegionNameInBytes, Bytes.toBytes(dstServer.getServerName().getServerName()));
+        admin.move(encodedRegionNameInBytes, dstServer.getServerName());
         while (dstServer.getOnlineRegion(regionInfo.getRegionName()) == null
                 || dstServer.getRegionsInTransitionInRS().containsKey(encodedRegionNameInBytes)
                 || srcServer.getRegionsInTransitionInRS().containsKey(encodedRegionNameInBytes)) {
@@ -2078,7 +2096,55 @@ public abstract class BaseTest {
     protected synchronized static boolean isAnyStoreRefCountLeaked()
             throws IOException {
         if (getUtility() != null) {
-            return CompatUtil.isAnyStoreRefCountLeaked(getUtility().getAdmin());
+            return isAnyStoreRefCountLeaked(getUtility().getAdmin());
+        }
+        return false;
+    }
+
+    /**
+     * HBase 2.3+ has storeRefCount available in RegionMetrics
+     *
+     * @param admin Admin instance
+     * @return true if any region has refCount leakage
+     * @throws IOException if something went wrong while connecting to Admin
+     */
+    public synchronized static boolean isAnyStoreRefCountLeaked(Admin admin)
+            throws IOException {
+        int retries = 5;
+        while (retries > 0) {
+            boolean isStoreRefCountLeaked = isStoreRefCountLeaked(admin);
+            if (!isStoreRefCountLeaked) {
+                return false;
+            }
+            retries--;
+            try {
+                Thread.sleep(1000);
+            } catch (InterruptedException e) {
+                LOGGER.error("Interrupted while sleeping", e);
+                break;
+            }
+        }
+        return true;
+    }
+
+    private static boolean isStoreRefCountLeaked(Admin admin)
+            throws IOException {
+        for (ServerName serverName : admin.getRegionServers()) {
+            for (RegionMetrics regionMetrics : admin.getRegionMetrics(serverName)) {
+                if (regionMetrics.getNameAsString().
+                    contains(TableName.META_TABLE_NAME.getNameAsString())) {
+                    // Just because something is trying to read from hbase:meta in the background
+                    // doesn't mean we leaked a scanner, so skip this
+                    continue;
+                }
+                int regionTotalRefCount = regionMetrics.getStoreRefCount();
+                if (regionTotalRefCount > 0) {
+                    LOGGER.error("Region {} has refCount leak. Total refCount"
+                            + " of all storeFiles combined for the region: {}",
+                        regionMetrics.getNameAsString(), regionTotalRefCount);
+                    return true;
+                }
+            }
         }
         return false;
     }
