@@ -61,6 +61,7 @@ import org.apache.phoenix.monitoring.GlobalClientMetrics;
 import org.apache.phoenix.util.ReadOnlyProps;
 import org.junit.Before;
 import org.junit.ClassRule;
+import org.junit.Ignore;
 import org.junit.Test;
 import org.mockito.Mock;
 import org.mockito.Mockito;
@@ -252,19 +253,11 @@ public class ConnectionQueryServicesImplTest {
     private void testGetNextRegionStartKey(ConnectionQueryServicesImpl mockCqsi,
         HRegionLocation mockRegionLocation, byte[] key, boolean isCorrupted,
         HRegionLocation mockPrevRegionLocation) {
-        try {
-            mockCqsi.getNextRegionStartKey(mockRegionLocation, key, mockPrevRegionLocation);
-            if (isCorrupted) {
-                fail();
-            }
-        } catch (IOException e) {
-            if (!isCorrupted) {
-                fail();
-            }
-        }
+        mockCqsi.getNextRegionStartKey(mockRegionLocation, key, mockPrevRegionLocation);
 
         assertEquals(isCorrupted ? 1 : 0,
-                GlobalClientMetrics.GLOBAL_HBASE_COUNTER_METADATA_INCONSISTENCY.getMetric().getValue());
+                GlobalClientMetrics.GLOBAL_HBASE_COUNTER_METADATA_INCONSISTENCY.getMetric()
+                        .getValue());
     }
 
     @Test
