@@ -98,6 +98,7 @@ import org.apache.phoenix.compile.StatementNormalizer;
 import org.apache.phoenix.compile.SubqueryRewriter;
 import org.apache.phoenix.compile.SubselectRewriter;
 import org.apache.phoenix.compile.JoinCompiler.JoinTable;
+import org.apache.phoenix.coprocessor.CompactionScanner;
 import org.apache.phoenix.coprocessor.generated.MetaDataProtos.ClearCacheRequest;
 import org.apache.phoenix.coprocessor.generated.MetaDataProtos.ClearCacheResponse;
 import org.apache.phoenix.coprocessor.generated.MetaDataProtos.MetaDataService;
@@ -815,6 +816,26 @@ public class TestUtil {
         admin.flush(table);
     }
 
+    public static void minorCompact(HBaseTestingUtility utility, TableName table)
+            throws IOException, InterruptedException {
+        try {
+            CompactionScanner.setForceMinorCompaction(true);
+            Admin admin = utility.getAdmin();
+            admin.compact(table);
+            int waitForCompactionToCompleteCounter = 0;
+            while (CompactionScanner.getForceMinorCompaction()) {
+                waitForCompactionToCompleteCounter++;
+                if (waitForCompactionToCompleteCounter > 50) {
+                    Assert.fail();
+                }
+                Thread.sleep(3000);
+            }
+        }
+        finally {
+            CompactionScanner.setForceMinorCompaction(false);
+        }
+    }
+
     public static void majorCompact(HBaseTestingUtility utility, TableName table)
         throws IOException, InterruptedException {
         long compactionRequestedSCN = EnvironmentEdgeManager.currentTimeMillis();
@@ -977,7 +998,6 @@ public class TestUtil {
     public static CellCount getCellCount(Table table, boolean isRaw) throws IOException {
         Scan s = new Scan();
         s.setRaw(isRaw);
-        ;
         s.readAllVersions();
 
         CellCount cellCount = new CellCount();
@@ -1364,13 +1384,17 @@ public class TestUtil {
         assertEquals(expectedRowCount, count);
     }
 
-    public static void assertRawCellCount(Connection conn, TableName tableName,
-                                          byte[] row, int expectedCellCount)
-        throws SQLException, IOException {
+    public static int getRawCellCount(Connection conn, TableName tableName, byte[] row)
+            throws SQLException, IOException {
         ConnectionQueryServices cqs = conn.unwrap(PhoenixConnection.class).getQueryServices();
         Table table = cqs.getTable(tableName.getName());
         CellCount cellCount = getCellCount(table, true);
-        int count = cellCount.getCellCount(Bytes.toString(row));
+        return cellCount.getCellCount(Bytes.toString(row));
+    }
+    public static void assertRawCellCount(Connection conn, TableName tableName,
+                                          byte[] row, int expectedCellCount)
+        throws SQLException, IOException {
+        int count = getRawCellCount(conn, tableName, row);
         assertEquals(expectedCellCount, count);
     }
 
