@@ -1,11 +1,10 @@
 /*
- * Licensed to the Apache Software Foundation (ASF) under one
- * or more contributor license agreements.  See the NOTICE file
- * distributed with this work for additional information
- * regarding copyright ownership.  The ASF licenses this file
- * to you under the Apache License, Version 2.0 (the
- * "License"); you may not use this file except in compliance
- * with the License.  You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to you under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  * http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -30,11 +29,15 @@ public abstract class CompatPhoenixRpcScheduler extends RpcScheduler {
     protected RpcScheduler delegate;
 
     @Override
-    public boolean dispatch(CallRunner task) throws IOException, InterruptedException {
-        return compatDispatch(task);
+    public boolean dispatch(CallRunner task) {
+        try {
+            return compatDispatch(task);
+        } catch (Exception e) {
+            //This never happens with Hbase 2.5
+            throw new RuntimeException(e);
+        }
     }
 
     public abstract boolean compatDispatch(CallRunner task)
             throws IOException, InterruptedException;
 }
-
